@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -34,8 +34,8 @@ CKEDITOR.lang['eo'] =
 	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
 
 	// ARIA descriptions.
-	toolbar	: 'Toolbar', // MISSING
-	editor	: 'Rich Text Editor', // MISSING
+	toolbars	: 'Editor toolbars', // MISSING
+	editor		: 'Rich Text Editor', // MISSING
 
 	// Toolbar buttons without dialogs.
 	source			: 'Fonto',
@@ -56,6 +56,7 @@ CKEDITOR.lang['eo'] =
 	superscript		: 'Superskribo',
 	horizontalrule	: 'Enmeti Horizonta Linio',
 	pagebreak		: 'Insert Page Break for Printing', // MISSING
+	pagebreakAlt		: 'Page Break', // MISSING
 	unlink			: 'Forigi Ligilon',
 	undo			: 'Malfari',
 	redo			: 'Refari',
@@ -105,6 +106,23 @@ CKEDITOR.lang['eo'] =
 		targetTop		: 'Topmost Window (_top)', // MISSING
 		targetSelf		: 'Same Window (_self)', // MISSING
 		targetParent	: 'Parent Window (_parent)', // MISSING
+		langDirLTR		: 'Left to Right (LTR)', // MISSING
+		langDirRTL		: 'Right to Left (RTL)', // MISSING
+		styles			: 'Style', // MISSING
+		cssClasses		: 'Stylesheet Classes', // MISSING
+		width			: 'Larĝo',
+		height			: 'Alto',
+		align			: 'Ĝisrandigo',
+		alignLeft		: 'Maldekstre',
+		alignRight		: 'Dekstre',
+		alignCenter		: 'Centre',
+		alignTop		: 'Supre',
+		alignMiddle		: 'Centre',
+		alignBottom		: 'Malsupre',
+		invalidHeight	: 'Height must be a number.', // MISSING
+		invalidWidth	: 'Width must be a number.', // MISSING
+		invalidCssLength	: 'Value specified for the "%1" field must be a positive number with or without a valid CSS measurement unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
+		invalidHtmlLength	: 'Value specified for the "%1" field must be a positive number with or without a valid HTML measurement unit (px or %).', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, unavailable</span>' // MISSING
@@ -151,9 +169,7 @@ CKEDITOR.lang['eo'] =
 		popupFullScreen	: 'Tutekrane (IE)',
 		popupScrollBars	: 'Rulumlisteloj',
 		popupDependent	: 'Dependa (Netscape)',
-		popupWidth		: 'Larĝo',
 		popupLeft		: 'Pozicio de Maldekstro',
-		popupHeight		: 'Alto',
 		popupTop		: 'Pozicio de Supro',
 		id				: 'Id', // MISSING
 		langDir			: 'Skribdirekto',
@@ -161,18 +177,19 @@ CKEDITOR.lang['eo'] =
 		langDirRTL		: 'De dekstro maldekstren (RTL)',
 		acccessKey		: 'Fulmoklavo',
 		name			: 'Nomo',
-		langCode		: 'Skribdirekto',
-		tabIndex		: 'Taba Ordo',
-		advisoryTitle	: 'Indika Titolo',
+		langCode			: 'Skribdirekto',
+		tabIndex			: 'Taba Ordo',
+		advisoryTitle		: 'Indika Titolo',
 		advisoryContentType	: 'Indika Enhavotipo',
 		cssClasses		: 'Klasoj de Stilfolioj',
 		charset			: 'Signaro de la Ligita Rimedo',
 		styles			: 'Stilo',
-		selectAnchor	: 'Elekti Ankron',
+		rel			: 'Relationship', // MISSING
+		selectAnchor		: 'Elekti Ankron',
 		anchorName		: 'Per Ankronomo',
-		anchorId		: 'Per Elementidentigilo',
-		emailAddress	: 'Retadreso',
-		emailSubject	: 'Temlinio',
+		anchorId			: 'Per Elementidentigilo',
+		emailAddress		: 'Retadreso',
+		emailSubject		: 'Temlinio',
 		emailBody		: 'Mesaĝa korpo',
 		noAnchors		: '<Ne disponeblas ankroj en la dokumento>',
 		noUrl			: 'Bonvolu entajpi la URL-on',
@@ -186,7 +203,8 @@ CKEDITOR.lang['eo'] =
 		menu		: 'Ankraj Atributoj',
 		title		: 'Ankraj Atributoj',
 		name		: 'Ankra Nomo',
-		errorName	: 'Bv tajpi la ankran nomon'
+		errorName	: 'Bv tajpi la ankran nomon',
+		remove		: 'Remove Anchor' // MISSING
 	},
 
 	// List style dialog
@@ -196,6 +214,7 @@ CKEDITOR.lang['eo'] =
 		bulletedTitle		: 'Bulleted List Properties', // MISSING
 		type				: 'Type', // MISSING
 		start				: 'Start', // MISSING
+		validateStartNumber				:'List start number must be a whole number.', // MISSING
 		circle				: 'Circle', // MISSING
 		disc				: 'Disc', // MISSING
 		square				: 'Square', // MISSING
@@ -238,15 +257,9 @@ CKEDITOR.lang['eo'] =
 		rows		: 'Linioj',
 		columns		: 'Kolumnoj',
 		border		: 'Bordero',
-		align		: 'Ĝisrandigo',
-		alignLeft	: 'Maldekstre',
-		alignCenter	: 'Centre',
-		alignRight	: 'Dekstre',
-		width		: 'Larĝo',
 		widthPx		: 'Bitbilderoj',
 		widthPc		: 'elcentoj',
 		widthUnit	: 'width unit', // MISSING
-		height		: 'Alto',
 		cellSpace	: 'Interspacigo de Ĉeloj',
 		cellPad		: 'Ĉirkaŭenhava Plenigado',
 		caption		: 'Titolo',
@@ -261,8 +274,8 @@ CKEDITOR.lang['eo'] =
 		invalidBorder	: 'Border size must be a number.', // MISSING
 		invalidWidth	: 'Table width must be a number.', // MISSING
 		invalidHeight	: 'Table height must be a number.', // MISSING
-		invalidCellSpacing	: 'Cell spacing must be a number.', // MISSING
-		invalidCellPadding	: 'Cell padding must be a number.', // MISSING
+		invalidCellSpacing	: 'Cell spacing must be a positive number.', // MISSING
+		invalidCellPadding	: 'Cell padding must be a positive number.', // MISSING
 
 		cell :
 		{
@@ -282,9 +295,6 @@ CKEDITOR.lang['eo'] =
 			wordWrap		: 'Word Wrap', // MISSING
 			hAlign			: 'Horizontal Alignment', // MISSING
 			vAlign			: 'Vertical Alignment', // MISSING
-			alignTop		: 'Top', // MISSING
-			alignMiddle		: 'Middle', // MISSING
-			alignBottom		: 'Bottom', // MISSING
 			alignBaseline	: 'Baseline', // MISSING
 			bgColor			: 'Background Color', // MISSING
 			borderColor		: 'Border Color', // MISSING
@@ -405,24 +415,16 @@ CKEDITOR.lang['eo'] =
 		btnUpload	: 'Sendu al Servilo',
 		upload		: 'Alŝuti',
 		alt			: 'Anstataŭiga Teksto',
-		width		: 'Larĝo',
-		height		: 'Alto',
 		lockRatio	: 'Konservi Proporcion',
-		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Origina Grando',
 		border		: 'Bordero',
 		hSpace		: 'HSpaco',
 		vSpace		: 'VSpaco',
-		align		: 'Ĝisrandigo',
-		alignLeft	: 'Maldekstre',
-		alignRight	: 'Dekstre',
 		alertUrl	: 'Bonvolu tajpi la URL de la bildo',
 		linkTab		: 'Link', // MISSING
 		button2Img	: 'Do you want to transform the selected image button on a simple image?', // MISSING
 		img2Button	: 'Do you want to transform the selected image on a image button?', // MISSING
 		urlMissing	: 'Image source URL is missing.', // MISSING
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
 		validateBorder	: 'Border must be a whole number.', // MISSING
 		validateHSpace	: 'HSpace must be a whole number.', // MISSING
 		validateVSpace	: 'VSpace must be a whole number.' // MISSING
@@ -446,16 +448,10 @@ CKEDITOR.lang['eo'] =
 		accessAlways	: 'Always', // MISSING
 		accessSameDomain: 'Same domain', // MISSING
 		accessNever		: 'Never', // MISSING
-		align			: 'Ĝisrandigo',
-		alignLeft		: 'Maldekstre',
 		alignAbsBottom	: 'Abs Malsupre',
 		alignAbsMiddle	: 'Abs Centre',
 		alignBaseline	: 'Je Malsupro de Teksto',
-		alignBottom		: 'Malsupre',
-		alignMiddle		: 'Centre',
-		alignRight		: 'Dekstre',
 		alignTextTop	: 'Je Supro de Teksto',
-		alignTop		: 'Supre',
 		quality			: 'Quality', // MISSING
 		qualityBest		: 'Best', // MISSING
 		qualityHigh		: 'High', // MISSING
@@ -469,13 +465,9 @@ CKEDITOR.lang['eo'] =
 		windowMode		: 'Window mode', // MISSING
 		flashvars		: 'Variables for Flash', // MISSING
 		bgcolor			: 'Fona Koloro',
-		width			: 'Larĝo',
-		height			: 'Alto',
 		hSpace			: 'HSpaco',
 		vSpace			: 'VSpaco',
 		validateSrc		: 'Bonvolu entajpi la URL-on',
-		validateWidth	: 'Width must be a number.', // MISSING
-		validateHeight	: 'Height must be a number.', // MISSING
 		validateHSpace	: 'HSpace must be a number.', // MISSING
 		validateVSpace	: 'VSpace must be a number.' // MISSING
 	},
@@ -610,6 +602,15 @@ CKEDITOR.lang['eo'] =
 		remove				: 'Remove Div' // MISSING
   	},
 
+	iframe :
+	{
+		title		: 'IFrame Properties', // MISSING
+		toolbar		: 'IFrame', // MISSING
+		noUrl		: 'Please type the iframe URL', // MISSING
+		scrolling	: 'Enable scrollbars', // MISSING
+		border		: 'Show frame border' // MISSING
+	},
+
 	font :
 	{
 		label		: 'Tiparo',
@@ -642,7 +643,7 @@ CKEDITOR.lang['eo'] =
 		'008080' : 'Teal', // MISSING
 		'000080' : 'Navy', // MISSING
 		'4B0082' : 'Indigo', // MISSING
-		'696969' : 'Dim Gray', // MISSING
+		'696969' : 'Dark Gray', // MISSING
 		'B22222' : 'Fire Brick', // MISSING
 		'A52A2A' : 'Brown', // MISSING
 		'DAA520' : 'Golden Rod', // MISSING
@@ -658,7 +659,7 @@ CKEDITOR.lang['eo'] =
 		'0FF' : 'Cyan', // MISSING
 		'00F' : 'Blue', // MISSING
 		'EE82EE' : 'Violet', // MISSING
-		'A9A9A9' : 'Dark Gray', // MISSING
+		'A9A9A9' : 'Dim Gray', // MISSING
 		'FFA07A' : 'Light Salmon', // MISSING
 		'FFA500' : 'Orange', // MISSING
 		'FFFF00' : 'Yellow', // MISSING
@@ -707,7 +708,7 @@ CKEDITOR.lang['eo'] =
 		dic_restore		: 'Restore', // MISSING
 		dic_delete		: 'Delete', // MISSING
 		dic_rename		: 'Rename', // MISSING
-		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type it\'s name and click the Restore button.', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type its name and click the Restore button.', // MISSING
 
 		aboutTab		: 'About' // MISSING
 	},
@@ -716,6 +717,8 @@ CKEDITOR.lang['eo'] =
 	{
 		title		: 'About CKEditor', // MISSING
 		dlgTitle	: 'About CKEditor', // MISSING
+		help	: 'Check $1 for help.', // MISSING
+		userGuide : 'CKEditor User\'s Guide', // MISSING
 		moreInfo	: 'For licensing information please visit our web site:', // MISSING
 		copy		: 'Copyright &copy; $1. All rights reserved.' // MISSING
 	},
@@ -725,10 +728,11 @@ CKEDITOR.lang['eo'] =
 
 	fakeobjects :
 	{
-		anchor	: 'Anchor', // MISSING
-		flash	: 'Flash Animation', // MISSING
-		div		: 'Page Break', // MISSING
-		unknown	: 'Unknown Object' // MISSING
+		anchor		: 'Anchor', // MISSING
+		flash		: 'Flash Animation', // MISSING
+		iframe		: 'IFrame', // MISSING
+		hiddenfield	: 'Hidden Field', // MISSING
+		unknown		: 'Unknown Object' // MISSING
 	},
 
 	resize : 'Drag to resize', // MISSING
@@ -743,5 +747,66 @@ CKEDITOR.lang['eo'] =
 	},
 
 	toolbarCollapse	: 'Collapse Toolbar', // MISSING
-	toolbarExpand	: 'Expand Toolbar' // MISSING
+	toolbarExpand	: 'Expand Toolbar', // MISSING
+
+	toolbarGroups :
+	{
+		document : 'Document', // MISSING
+		clipboard : 'Clipboard/Undo', // MISSING
+		editing : 'Editing', // MISSING
+		forms : 'Forms', // MISSING
+		basicstyles : 'Basic Styles', // MISSING
+		paragraph : 'Paragraph', // MISSING
+		links : 'Links', // MISSING
+		insert : 'Insert', // MISSING
+		styles : 'Styles', // MISSING
+		colors : 'Colors', // MISSING
+		tools : 'Tools' // MISSING
+	},
+
+	bidi :
+	{
+		ltr : 'Text direction from left to right', // MISSING
+		rtl : 'Text direction from right to left' // MISSING
+	},
+
+	docprops :
+	{
+		label : 'Dokumentaj Atributoj',
+		title : 'Dokumentaj Atributoj',
+		design : 'Design', // MISSING
+		meta : 'Metadatumoj',
+		chooseColor : 'Choose', // MISSING
+		other : '<other>',
+		docTitle :	'Paĝotitolo',
+		charset : 	'Signara Kodo',
+		charsetOther : 'Alia Signara Kodo',
+		charsetASCII : 'ASCII', // MISSING
+		charsetCE : 'Central European', // MISSING
+		charsetCT : 'Chinese Traditional (Big5)', // MISSING
+		charsetCR : 'Cyrillic', // MISSING
+		charsetGR : 'Greek', // MISSING
+		charsetJP : 'Japanese', // MISSING
+		charsetKR : 'Korean', // MISSING
+		charsetTR : 'Turkish', // MISSING
+		charsetUN : 'Unicode (UTF-8)', // MISSING
+		charsetWE : 'Western European', // MISSING
+		docType : 'Dokumenta Tipo',
+		docTypeOther : 'Alia Dokumenta Tipo',
+		xhtmlDec : 'Inkluzivi XHTML Deklaroj',
+		bgColor : 'Fona Koloro',
+		bgImage : 'URL de Fona Bildo',
+		bgFixed : 'Neruluma Fono',
+		txtColor : 'Teksta Koloro',
+		margin : 'Paĝaj Marĝenoj',
+		marginTop : 'Supra',
+		marginLeft : 'Maldekstra',
+		marginRight : 'Dekstra',
+		marginBottom : 'Malsupra',
+		metaKeywords : 'Ŝlosilvortoj de la Dokumento (apartigita de komoj)',
+		metaDescription : 'Dokumenta Priskribo',
+		metaAuthor : 'Verkinto',
+		metaCopyright : 'Kopirajto',
+		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
+	}
 };
