@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -31,7 +31,11 @@ CKEDITOR.lang['fa'] =
 	 * Screenreader titles. Please note that screenreaders are not always capable
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle		: 'Rich text editor, %1', // MISSING
+	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+
+	// ARIA descriptions.
+	toolbars	: 'Editor toolbars', // MISSING
+	editor		: 'Rich Text Editor', // MISSING
 
 	// Toolbar buttons without dialogs.
 	source			: 'منبع',
@@ -52,6 +56,7 @@ CKEDITOR.lang['fa'] =
 	superscript		: 'بالانویس',
 	horizontalrule	: 'گنجاندن خط ِافقی',
 	pagebreak		: 'گنجاندن شکستگی ِپایان ِبرگه',
+	pagebreakAlt		: 'Page Break', // MISSING
 	unlink			: 'برداشتن پیوند',
 	undo			: 'واچیدن',
 	redo			: 'بازچیدن',
@@ -68,12 +73,12 @@ CKEDITOR.lang['fa'] =
 		flash			: 'Flash',
 		form			: 'فرم',
 		checkbox		: 'خانهٴ گزینهای',
-		radio		: 'دکمهٴ رادیویی',
+		radio			: 'دکمهٴ رادیویی',
 		textField		: 'فیلد متنی',
 		textarea		: 'ناحیهٴ متنی',
 		hiddenField		: 'فیلد پنهان',
 		button			: 'دکمه',
-		select	: 'فیلد چندگزینهای',
+		select			: 'فیلد چندگزینهای',
 		imageButton		: 'دکمهٴ تصویری',
 		notSet			: '<تعیننشده>',
 		id				: 'شناسه',
@@ -88,27 +93,59 @@ CKEDITOR.lang['fa'] =
 		cssStyle		: 'شیوه(style)',
 		ok				: 'پذیرش',
 		cancel			: 'انصراف',
+		close			: 'Close', // MISSING
+		preview			: 'Preview', // MISSING
 		generalTab		: 'General', // MISSING
 		advancedTab		: 'پیشرفته',
-		validateNumberFailed	: 'This value is not a number.', // MISSING
+		validateNumberFailed : 'This value is not a number.', // MISSING
 		confirmNewPage	: 'Any unsaved changes to this content will be lost. Are you sure you want to load new page?', // MISSING
 		confirmCancel	: 'Some of the options have been changed. Are you sure to close the dialog?', // MISSING
+		options			: 'Options', // MISSING
+		target			: 'Target', // MISSING
+		targetNew		: 'New Window (_blank)', // MISSING
+		targetTop		: 'Topmost Window (_top)', // MISSING
+		targetSelf		: 'Same Window (_self)', // MISSING
+		targetParent	: 'Parent Window (_parent)', // MISSING
+		langDirLTR		: 'Left to Right (LTR)', // MISSING
+		langDirRTL		: 'Right to Left (RTL)', // MISSING
+		styles			: 'Style', // MISSING
+		cssClasses		: 'Stylesheet Classes', // MISSING
+		width			: 'پهنا',
+		height			: 'درازا',
+		align			: 'چینش',
+		alignLeft		: 'چپ',
+		alignRight		: 'راست',
+		alignCenter		: 'وسط',
+		alignTop		: 'بالا',
+		alignMiddle		: 'وسط',
+		alignBottom		: 'پائین',
+		invalidHeight	: 'Height must be a number.', // MISSING
+		invalidWidth	: 'Width must be a number.', // MISSING
+		invalidCssLength	: 'Value specified for the "%1" field must be a positive number with or without a valid CSS measurement unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
+		invalidHtmlLength	: 'Value specified for the "%1" field must be a positive number with or without a valid HTML measurement unit (px or %).', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, unavailable</span>' // MISSING
 	},
 
+	contextmenu :
+	{
+		options : 'Context Menu Options' // MISSING
+	},
+
 	// Special char dialog.
 	specialChar		:
 	{
 		toolbar		: 'گنجاندن نویسهٴ ویژه',
-		title		: 'گزینش نویسهٴویژه'
+		title		: 'گزینش نویسهٴویژه',
+		options : 'Special Character Options' // MISSING
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'گنجاندن/ویرایش ِپیوند',
+		other 		: '<سایر>',
 		menu		: 'ویرایش پیوند',
 		title		: 'پیوند',
 		info		: 'اطلاعات پیوند',
@@ -116,50 +153,43 @@ CKEDITOR.lang['fa'] =
 		upload		: 'انتقال به سرور',
 		advanced	: 'پیشرفته',
 		type		: 'نوع پیوند',
+		toUrl		: 'URL', // MISSING
 		toAnchor	: 'لنگر در همین صفحه',
 		toEmail		: 'پست الکترونیکی',
-		target		: 'مقصد',
-		targetNotSet	: '<تعیننشده>',
-		targetFrame	: '<فریم>',
-		targetPopup	: '<پنجرهٴ پاپاپ>',
-		targetNew	: 'پنجرهٴ دیگر (_blank)',
-		targetTop	: 'بالاترین پنجره (_top)',
-		targetSelf	: 'همان پنجره (_self)',
-		targetParent	: 'پنجرهٴ والد (_parent)',
+		targetFrame		: '<فریم>',
+		targetPopup		: '<پنجرهٴ پاپاپ>',
 		targetFrameName	: 'نام فریم مقصد',
 		targetPopupName	: 'نام پنجرهٴ پاپاپ',
 		popupFeatures	: 'ویژگیهای پنجرهٴ پاپاپ',
 		popupResizable	: 'Resizable', // MISSING
 		popupStatusBar	: 'نوار وضعیت',
-		popupLocationBar	: 'نوار موقعیت',
+		popupLocationBar: 'نوار موقعیت',
 		popupToolbar	: 'نوارابزار',
 		popupMenuBar	: 'نوار منو',
 		popupFullScreen	: 'تمامصفحه (IE)',
 		popupScrollBars	: 'میلههای پیمایش',
 		popupDependent	: 'وابسته (Netscape)',
-		popupWidth		: 'پهنا',
 		popupLeft		: 'موقعیت ِچپ',
-		popupHeight		: 'درازا',
 		popupTop		: 'موقعیت ِبالا',
 		id				: 'Id', // MISSING
 		langDir			: 'جهتنمای زبان',
-		langDirNotSet	: '<تعیننشده>',
 		langDirLTR		: 'چپ به راست (LTR)',
 		langDirRTL		: 'راست به چپ (RTL)',
 		acccessKey		: 'کلید دستیابی',
 		name			: 'نام',
-		langCode		: 'جهتنمای زبان',
-		tabIndex		: 'نمایهٴ دسترسی با Tab',
-		advisoryTitle	: 'عنوان کمکی',
+		langCode			: 'جهتنمای زبان',
+		tabIndex			: 'نمایهٴ دسترسی با Tab',
+		advisoryTitle		: 'عنوان کمکی',
 		advisoryContentType	: 'نوع محتوای کمکی',
 		cssClasses		: 'کلاسهای شیوهنامه(Stylesheet)',
 		charset			: 'نویسهگان منبع ِپیوندشده',
 		styles			: 'شیوه(style)',
-		selectAnchor	: 'یک لنگر برگزینید',
+		rel			: 'Relationship', // MISSING
+		selectAnchor		: 'یک لنگر برگزینید',
 		anchorName		: 'با نام لنگر',
-		anchorId		: 'با شناسهٴ المان',
-		emailAddress	: 'نشانی پست الکترونیکی',
-		emailSubject	: 'موضوع پیام',
+		anchorId			: 'با شناسهٴ المان',
+		emailAddress		: 'نشانی پست الکترونیکی',
+		emailSubject		: 'موضوع پیام',
 		emailBody		: 'متن پیام',
 		noAnchors		: '(در این سند لنگری دردسترس نیست)',
 		noUrl			: 'لطفا URL پیوند را بنویسید',
@@ -173,7 +203,32 @@ CKEDITOR.lang['fa'] =
 		menu		: 'ویژگیهای لنگر',
 		title		: 'ویژگیهای لنگر',
 		name		: 'نام لنگر',
-		errorName	: 'لطفا نام لنگر را بنویسید'
+		errorName	: 'لطفا نام لنگر را بنویسید',
+		remove		: 'Remove Anchor' // MISSING
+	},
+
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'Numbered List Properties', // MISSING
+		bulletedTitle		: 'Bulleted List Properties', // MISSING
+		type				: 'Type', // MISSING
+		start				: 'Start', // MISSING
+		validateStartNumber				:'List start number must be a whole number.', // MISSING
+		circle				: 'Circle', // MISSING
+		disc				: 'Disc', // MISSING
+		square				: 'Square', // MISSING
+		none				: 'None', // MISSING
+		notset				: '<not set>', // MISSING
+		armenian			: 'Armenian numbering', // MISSING
+		georgian			: 'Georgian numbering (an, ban, gan, etc.)', // MISSING
+		lowerRoman			: 'Lower Roman (i, ii, iii, iv, v, etc.)', // MISSING
+		upperRoman			: 'Upper Roman (I, II, III, IV, V, etc.)', // MISSING
+		lowerAlpha			: 'Lower Alpha (a, b, c, d, e, etc.)', // MISSING
+		upperAlpha			: 'Upper Alpha (A, B, C, D, E, etc.)', // MISSING
+		lowerGreek			: 'Lower Greek (alpha, beta, gamma, etc.)', // MISSING
+		decimal				: 'Decimal (1, 2, 3, etc.)', // MISSING
+		decimalLeadingZero	: 'Decimal leading zero (01, 02, 03, etc.)' // MISSING
 	},
 
 	// Find And Replace Dialog
@@ -202,15 +257,9 @@ CKEDITOR.lang['fa'] =
 		rows		: 'سطرها',
 		columns		: 'ستونها',
 		border		: 'اندازهٴ لبه',
-		align		: 'چینش',
-		alignNotSet	: '<تعیننشده>',
-		alignLeft	: 'چپ',
-		alignCenter	: 'وسط',
-		alignRight	: 'راست',
-		width		: 'پهنا',
 		widthPx		: 'پیکسل',
 		widthPc		: 'درصد',
-		height		: 'درازا',
+		widthUnit	: 'width unit', // MISSING
 		cellSpace	: 'فاصلهٴ میان سلولها',
 		cellPad		: 'فاصلهٴ پرشده در سلول',
 		caption		: 'عنوان',
@@ -225,8 +274,8 @@ CKEDITOR.lang['fa'] =
 		invalidBorder	: 'Border size must be a number.', // MISSING
 		invalidWidth	: 'Table width must be a number.', // MISSING
 		invalidHeight	: 'Table height must be a number.', // MISSING
-		invalidCellSpacing	: 'Cell spacing must be a number.', // MISSING
-		invalidCellPadding	: 'Cell padding must be a number.', // MISSING
+		invalidCellSpacing	: 'Cell spacing must be a positive number.', // MISSING
+		invalidCellPadding	: 'Cell padding must be a positive number.', // MISSING
 
 		cell :
 		{
@@ -246,9 +295,6 @@ CKEDITOR.lang['fa'] =
 			wordWrap		: 'Word Wrap', // MISSING
 			hAlign			: 'Horizontal Alignment', // MISSING
 			vAlign			: 'Vertical Alignment', // MISSING
-			alignTop		: 'Top', // MISSING
-			alignMiddle		: 'Middle', // MISSING
-			alignBottom		: 'Bottom', // MISSING
 			alignBaseline	: 'Baseline', // MISSING
 			bgColor			: 'Background Color', // MISSING
 			borderColor		: 'Border Color', // MISSING
@@ -260,7 +306,7 @@ CKEDITOR.lang['fa'] =
 			invalidHeight	: 'Cell height must be a number.', // MISSING
 			invalidRowSpan	: 'Rows span must be a whole number.', // MISSING
 			invalidColSpan	: 'Columns span must be a whole number.', // MISSING
-			chooseColor : 'Choose' // MISSING
+			chooseColor		: 'Choose' // MISSING
 		},
 
 		row :
@@ -307,13 +353,7 @@ CKEDITOR.lang['fa'] =
 		menu		: 'ویژگیهای فرم',
 		action		: 'رویداد',
 		method		: 'متد',
-		encoding	: 'Encoding', // MISSING
-		target		: 'مقصد',
-		targetNotSet	: '<تعیننشده>',
-		targetNew	: 'پنجرهٴ دیگر (_blank)',
-		targetTop	: 'بالاترین پنجره (_top)',
-		targetSelf	: 'همان پنجره (_self)',
-		targetParent	: 'پنجرهٴ والد (_parent)'
+		encoding	: 'Encoding' // MISSING
 	},
 
 	// Select Field Dialog.
@@ -371,27 +411,23 @@ CKEDITOR.lang['fa'] =
 		title		: 'ویژگیهای تصویر',
 		titleButton	: 'ویژگیهای دکمهٴ تصویری',
 		menu		: 'ویژگیهای تصویر',
-		infoTab	: 'اطلاعات تصویر',
+		infoTab		: 'اطلاعات تصویر',
 		btnUpload	: 'به سرور بفرست',
-		url		: 'URL',
-		upload	: 'انتقال به سرور',
-		alt		: 'متن جایگزین',
-		width		: 'پهنا',
-		height	: 'درازا',
+		upload		: 'انتقال به سرور',
+		alt			: 'متن جایگزین',
 		lockRatio	: 'قفلکردن ِنسبت',
 		resetSize	: 'بازنشانی اندازه',
-		border	: 'لبه',
-		hSpace	: 'فاصلهٴ افقی',
-		vSpace	: 'فاصلهٴ عمودی',
-		align		: 'چینش',
-		alignLeft	: 'چپ',
-		alignRight	: 'راست',
-		preview	: 'پیشنمایش',
+		border		: 'لبه',
+		hSpace		: 'فاصلهٴ افقی',
+		vSpace		: 'فاصلهٴ عمودی',
 		alertUrl	: 'لطفا URL تصویر را بنویسید',
-		linkTab	: 'پیوند',
+		linkTab		: 'پیوند',
 		button2Img	: 'Do you want to transform the selected image button on a simple image?', // MISSING
 		img2Button	: 'Do you want to transform the selected image on a image button?', // MISSING
-		urlMissing : 'Image source URL is missing.' // MISSING
+		urlMissing	: 'Image source URL is missing.', // MISSING
+		validateBorder	: 'Border must be a whole number.', // MISSING
+		validateHSpace	: 'HSpace must be a whole number.', // MISSING
+		validateVSpace	: 'VSpace must be a whole number.' // MISSING
 	},
 
 	// Flash Dialog
@@ -399,51 +435,41 @@ CKEDITOR.lang['fa'] =
 	{
 		properties		: 'ویژگیهای Flash',
 		propertiesTab	: 'Properties', // MISSING
-		title		: 'ویژگیهای Flash',
-		chkPlay		: 'آغاز ِخودکار',
-		chkLoop		: 'اجرای پیاپی',
-		chkMenu		: 'دردسترسبودن منوی Flash',
-		chkFull		: 'Allow Fullscreen', // MISSING
- 		scale		: 'مقیاس',
+		title			: 'ویژگیهای Flash',
+		chkPlay			: 'آغاز ِخودکار',
+		chkLoop			: 'اجرای پیاپی',
+		chkMenu			: 'دردسترسبودن منوی Flash',
+		chkFull			: 'Allow Fullscreen', // MISSING
+ 		scale			: 'مقیاس',
 		scaleAll		: 'نمایش همه',
 		scaleNoBorder	: 'بدون کران',
 		scaleFit		: 'جایگیری کامل',
 		access			: 'Script Access', // MISSING
 		accessAlways	: 'Always', // MISSING
-		accessSameDomain	: 'Same domain', // MISSING
-		accessNever	: 'Never', // MISSING
-		align		: 'چینش',
-		alignLeft	: 'چپ',
-		alignAbsBottom: 'پائین مطلق',
-		alignAbsMiddle: 'وسط مطلق',
+		accessSameDomain: 'Same domain', // MISSING
+		accessNever		: 'Never', // MISSING
+		alignAbsBottom	: 'پائین مطلق',
+		alignAbsMiddle	: 'وسط مطلق',
 		alignBaseline	: 'خطپایه',
-		alignBottom	: 'پائین',
-		alignMiddle	: 'وسط',
-		alignRight	: 'راست',
 		alignTextTop	: 'متن بالا',
-		alignTop	: 'بالا',
-		quality		: 'Quality', // MISSING
-		qualityBest		 : 'Best', // MISSING
-		qualityHigh		 : 'High', // MISSING
-		qualityAutoHigh	 : 'Auto High', // MISSING
-		qualityMedium	 : 'Medium', // MISSING
-		qualityAutoLow	 : 'Auto Low', // MISSING
-		qualityLow		 : 'Low', // MISSING
-		windowModeWindow	 : 'Window', // MISSING
-		windowModeOpaque	 : 'Opaque', // MISSING
-		windowModeTransparent	 : 'Transparent', // MISSING
-		windowMode	: 'Window mode', // MISSING
-		flashvars	: 'Variables for Flash', // MISSING
-		bgcolor	: 'رنگ پسزمینه',
-		width	: 'پهنا',
-		height	: 'درازا',
-		hSpace	: 'فاصلهٴ افقی',
-		vSpace	: 'فاصلهٴ عمودی',
-		validateSrc : 'لطفا URL پیوند را بنویسید',
-		validateWidth : 'Width must be a number.', // MISSING
-		validateHeight : 'Height must be a number.', // MISSING
-		validateHSpace : 'HSpace must be a number.', // MISSING
-		validateVSpace : 'VSpace must be a number.' // MISSING
+		quality			: 'Quality', // MISSING
+		qualityBest		: 'Best', // MISSING
+		qualityHigh		: 'High', // MISSING
+		qualityAutoHigh	: 'Auto High', // MISSING
+		qualityMedium	: 'Medium', // MISSING
+		qualityAutoLow	: 'Auto Low', // MISSING
+		qualityLow		: 'Low', // MISSING
+		windowModeWindow: 'Window', // MISSING
+		windowModeOpaque: 'Opaque', // MISSING
+		windowModeTransparent : 'Transparent', // MISSING
+		windowMode		: 'Window mode', // MISSING
+		flashvars		: 'Variables for Flash', // MISSING
+		bgcolor			: 'رنگ پسزمینه',
+		hSpace			: 'فاصلهٴ افقی',
+		vSpace			: 'فاصلهٴ عمودی',
+		validateSrc		: 'لطفا URL پیوند را بنویسید',
+		validateHSpace	: 'HSpace must be a number.', // MISSING
+		validateVSpace	: 'VSpace must be a number.' // MISSING
 	},
 
 	// Speller Pages Dialog
@@ -472,25 +498,27 @@ CKEDITOR.lang['fa'] =
 	smiley :
 	{
 		toolbar	: 'خندانک',
-		title	: 'گنجاندن خندانک'
+		title	: 'گنجاندن خندانک',
+		options : 'Smiley Options' // MISSING
 	},
 
 	elementsPath :
 	{
+		eleLabel : 'Elements path', // MISSING
 		eleTitle : '%1 element' // MISSING
 	},
 
-	numberedlist : 'فهرست شمارهدار',
-	bulletedlist : 'فهرست نقطهای',
-	indent : 'افزایش تورفتگی',
-	outdent : 'کاهش تورفتگی',
+	numberedlist	: 'فهرست شمارهدار',
+	bulletedlist	: 'فهرست نقطهای',
+	indent			: 'افزایش تورفتگی',
+	outdent			: 'کاهش تورفتگی',
 
 	justify :
 	{
-		left : 'چپچین',
-		center : 'میانچین',
-		right : 'راستچین',
-		block : 'بلوکچین'
+		left	: 'چپچین',
+		center	: 'میانچین',
+		right	: 'راستچین',
+		block	: 'بلوکچین'
 	},
 
 	blockquote : 'بلوک نقل قول',
@@ -498,64 +526,63 @@ CKEDITOR.lang['fa'] =
 	clipboard :
 	{
 		title		: 'چسباندن',
-		cutError	: 'تنظیمات امنیتی مرورگر شما اجازه نمیدهد که ویرایشگر به طور خودکار عملکردهای برش را انجام دهد. لطفا با دکمههای صفحهکلید این کار را انجام دهید (Ctrl+X).',
-		copyError	: 'تنظیمات امنیتی مرورگر شما اجازه نمیدهد که ویرایشگر به طور خودکار عملکردهای کپیکردن را انجام دهد. لطفا با دکمههای صفحهکلید این کار را انجام دهید (Ctrl+C).',
-		pasteMsg	: 'لطفا متن را با کلیدهای (<STRONG>Ctrl+V</STRONG>) در این جعبهٴ متنی بچسبانید و <STRONG>پذیرش</STRONG> را بزنید.',
-		securityMsg	: 'به خاطر تنظیمات امنیتی مرورگر شما، ویرایشگر نمیتواند دسترسی مستقیم به دادههای clipboard داشته باشد. شما باید دوباره آنرا در این پنجره بچسبانید.'
+		cutError	: 'تنظیمات امنیتی مرورگر شما اجازه نمیدهد که ویرایشگر به طور خودکار عملکردهای برش را انجام دهد. لطفا با دکمههای صفحهکلید این کار را انجام دهید (Ctrl/Cmd+X).',
+		copyError	: 'تنظیمات امنیتی مرورگر شما اجازه نمیدهد که ویرایشگر به طور خودکار عملکردهای کپیکردن را انجام دهد. لطفا با دکمههای صفحهکلید این کار را انجام دهید (Ctrl/Cmd+C).',
+		pasteMsg	: 'لطفا متن را با کلیدهای (<STRONG>Ctrl/Cmd+V</STRONG>) در این جعبهٴ متنی بچسبانید و <STRONG>پذیرش</STRONG> را بزنید.',
+		securityMsg	: 'به خاطر تنظیمات امنیتی مرورگر شما، ویرایشگر نمیتواند دسترسی مستقیم به دادههای clipboard داشته باشد. شما باید دوباره آنرا در این پنجره بچسبانید.',
+		pasteArea	: 'Paste Area' // MISSING
 	},
 
 	pastefromword :
 	{
-		confirmCleanup : 'The text you want to paste seems to be copied from Word. Do you want to clean it before pasting?', // MISSING
-		toolbar : 'چسباندن از Word',
-		title : 'چسباندن از Word',
-		error : 'It was not possible to clean up the pasted data due to an internal error' // MISSING
+		confirmCleanup	: 'The text you want to paste seems to be copied from Word. Do you want to clean it before pasting?', // MISSING
+		toolbar			: 'چسباندن از Word',
+		title			: 'چسباندن از Word',
+		error			: 'It was not possible to clean up the pasted data due to an internal error' // MISSING
 	},
 
 	pasteText :
 	{
-		button : 'چسباندن به عنوان متن ِساده',
-		title : 'چسباندن به عنوان متن ِساده'
+		button	: 'چسباندن به عنوان متن ِساده',
+		title	: 'چسباندن به عنوان متن ِساده'
 	},
 
 	templates :
 	{
-		button : 'الگوها',
-		title : 'الگوهای محتویات',
-		insertOption: 'محتویات کنونی جایگزین شوند',
-		selectPromptMsg: 'لطفا الگوی موردنظر را برای بازکردن در ویرایشگر برگزینید<br>(محتویات کنونی از دست خواهند رفت):',
-		emptyListMsg : '(الگوئی تعریف نشده است)'
+		button			: 'الگوها',
+		title			: 'الگوهای محتویات',
+		options : 'Template Options', // MISSING
+		insertOption	: 'محتویات کنونی جایگزین شوند',
+		selectPromptMsg	: 'لطفا الگوی موردنظر را برای بازکردن در ویرایشگر برگزینید<br>(محتویات کنونی از دست خواهند رفت):',
+		emptyListMsg	: '(الگوئی تعریف نشده است)'
 	},
 
 	showBlocks : 'نمایش بلوکها',
 
 	stylesCombo :
 	{
-		label : 'سبک',
-		voiceLabel : 'Styles', // MISSING
-		panelVoiceLabel : 'Select a style', // MISSING
-		panelTitle1 : 'Block Styles', // MISSING
-		panelTitle2 : 'Inline Styles', // MISSING
-		panelTitle3 : 'Object Styles' // MISSING
+		label		: 'سبک',
+		panelTitle	: 'Formatting Styles', // MISSING
+		panelTitle1	: 'Block Styles', // MISSING
+		panelTitle2	: 'Inline Styles', // MISSING
+		panelTitle3	: 'Object Styles' // MISSING
 	},
 
 	format :
 	{
-		label : 'فرمت',
-		voiceLabel : 'Format', // MISSING
-		panelTitle : 'فرمت',
-		panelVoiceLabel : 'Select a paragraph format', // MISSING
+		label		: 'فرمت',
+		panelTitle	: 'فرمت',
 
-		tag_p : 'نرمال',
-		tag_pre : 'فرمتشده',
-		tag_address : 'آدرس',
-		tag_h1 : 'سرنویس 1',
-		tag_h2 : 'سرنویس 2',
-		tag_h3 : 'سرنویس 3',
-		tag_h4 : 'سرنویس 4',
-		tag_h5 : 'سرنویس 5',
-		tag_h6 : 'سرنویس 6',
-		tag_div : 'بند'
+		tag_p		: 'نرمال',
+		tag_pre		: 'فرمتشده',
+		tag_address	: 'آدرس',
+		tag_h1		: 'سرنویس 1',
+		tag_h2		: 'سرنویس 2',
+		tag_h3		: 'سرنویس 3',
+		tag_h4		: 'سرنویس 4',
+		tag_h5		: 'سرنویس 5',
+		tag_h6		: 'سرنویس 6',
+		tag_div		: 'بند'
 	},
 
 	div :
@@ -575,28 +602,36 @@ CKEDITOR.lang['fa'] =
 		remove				: 'Remove Div' // MISSING
   	},
 
+	iframe :
+	{
+		title		: 'IFrame Properties', // MISSING
+		toolbar		: 'IFrame', // MISSING
+		noUrl		: 'Please type the iframe URL', // MISSING
+		scrolling	: 'Enable scrollbars', // MISSING
+		border		: 'Show frame border' // MISSING
+	},
+
 	font :
 	{
-		label : 'قلم',
-		voiceLabel : 'Font', // MISSING
-		panelTitle : 'قلم',
-		panelVoiceLabel : 'Select a font' // MISSING
+		label		: 'قلم',
+		voiceLabel	: 'Font', // MISSING
+		panelTitle	: 'قلم'
 	},
 
 	fontSize :
 	{
-		label : 'اندازه',
-		voiceLabel : 'Font Size', // MISSING
-		panelTitle : 'اندازه',
-		panelVoiceLabel : 'Select a font size' // MISSING
+		label		: 'اندازه',
+		voiceLabel	: 'Font Size', // MISSING
+		panelTitle	: 'اندازه'
 	},
 
 	colorButton :
 	{
-		textColorTitle : 'رنگ متن',
-		bgColorTitle : 'رنگ پسزمینه',
-		auto : 'خودکار',
-		more : 'رنگهای بیشتر...'
+		textColorTitle	: 'رنگ متن',
+		bgColorTitle	: 'رنگ پسزمینه',
+		panelTitle		: 'Colors', // MISSING
+		auto			: 'خودکار',
+		more			: 'رنگهای بیشتر...'
 	},
 
 	colors :
@@ -608,7 +643,7 @@ CKEDITOR.lang['fa'] =
 		'008080' : 'Teal', // MISSING
 		'000080' : 'Navy', // MISSING
 		'4B0082' : 'Indigo', // MISSING
-		'696969' : 'Dim Gray', // MISSING
+		'696969' : 'Dark Gray', // MISSING
 		'B22222' : 'Fire Brick', // MISSING
 		'A52A2A' : 'Brown', // MISSING
 		'DAA520' : 'Golden Rod', // MISSING
@@ -624,7 +659,7 @@ CKEDITOR.lang['fa'] =
 		'0FF' : 'Cyan', // MISSING
 		'00F' : 'Blue', // MISSING
 		'EE82EE' : 'Violet', // MISSING
-		'A9A9A9' : 'Dark Gray', // MISSING
+		'A9A9A9' : 'Dim Gray', // MISSING
 		'FFA07A' : 'Light Salmon', // MISSING
 		'FFA500' : 'Orange', // MISSING
 		'FFFF00' : 'Yellow', // MISSING
@@ -645,30 +680,47 @@ CKEDITOR.lang['fa'] =
 
 	scayt :
 	{
-		title : 'Spell Check As You Type', // MISSING
-		enable : 'Enable SCAYT', // MISSING
-		disable : 'Disable SCAYT', // MISSING
-		about : 'About SCAYT', // MISSING
-		toggle : 'Toggle SCAYT', // MISSING
-		options : 'Options', // MISSING
-		langs : 'Languages', // MISSING
-		moreSuggestions : 'More suggestions', // MISSING
-		ignore : 'Ignore', // MISSING
-		ignoreAll : 'Ignore All', // MISSING
-		addWord : 'Add Word', // MISSING
-		emptyDic : 'Dictionary name should not be empty.', // MISSING
-		optionsTab : 'Options', // MISSING
-		languagesTab : 'Languages', // MISSING
-		dictionariesTab : 'Dictionaries', // MISSING
-		aboutTab : 'About' // MISSING
+		title			: 'Spell Check As You Type', // MISSING
+		opera_title		: 'Not supported by Opera', // MISSING
+		enable			: 'Enable SCAYT', // MISSING
+		disable			: 'Disable SCAYT', // MISSING
+		about			: 'About SCAYT', // MISSING
+		toggle			: 'Toggle SCAYT', // MISSING
+		options			: 'Options', // MISSING
+		langs			: 'Languages', // MISSING
+		moreSuggestions	: 'More suggestions', // MISSING
+		ignore			: 'Ignore', // MISSING
+		ignoreAll		: 'Ignore All', // MISSING
+		addWord			: 'Add Word', // MISSING
+		emptyDic		: 'Dictionary name should not be empty.', // MISSING
+
+		optionsTab		: 'Options', // MISSING
+		allCaps			: 'Ignore All-Caps Words', // MISSING
+		ignoreDomainNames : 'Ignore Domain Names', // MISSING
+		mixedCase		: 'Ignore Words with Mixed Case', // MISSING
+		mixedWithDigits	: 'Ignore Words with Numbers', // MISSING
+
+		languagesTab	: 'Languages', // MISSING
+
+		dictionariesTab	: 'Dictionaries', // MISSING
+		dic_field_name	: 'Dictionary name', // MISSING
+		dic_create		: 'Create', // MISSING
+		dic_restore		: 'Restore', // MISSING
+		dic_delete		: 'Delete', // MISSING
+		dic_rename		: 'Rename', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type its name and click the Restore button.', // MISSING
+
+		aboutTab		: 'About' // MISSING
 	},
 
 	about :
 	{
-		title : 'About CKEditor', // MISSING
-		dlgTitle : 'About CKEditor', // MISSING
-		moreInfo : 'For licensing information please visit our web site:', // MISSING
-		copy : 'Copyright &copy; $1. All rights reserved.' // MISSING
+		title		: 'About CKEditor', // MISSING
+		dlgTitle	: 'About CKEditor', // MISSING
+		help	: 'Check $1 for help.', // MISSING
+		userGuide : 'CKEditor User\'s Guide', // MISSING
+		moreInfo	: 'For licensing information please visit our web site:', // MISSING
+		copy		: 'Copyright &copy; $1. All rights reserved.' // MISSING
 	},
 
 	maximize : 'Maximize', // MISSING
@@ -676,22 +728,85 @@ CKEDITOR.lang['fa'] =
 
 	fakeobjects :
 	{
-		anchor : 'Anchor', // MISSING
-		flash : 'Flash Animation', // MISSING
-		div : 'Page Break', // MISSING
-		unknown : 'Unknown Object' // MISSING
+		anchor		: 'Anchor', // MISSING
+		flash		: 'Flash Animation', // MISSING
+		iframe		: 'IFrame', // MISSING
+		hiddenfield	: 'Hidden Field', // MISSING
+		unknown		: 'Unknown Object' // MISSING
 	},
 
 	resize : 'Drag to resize', // MISSING
 
 	colordialog :
 	{
-		title : 'Select color', // MISSING
-		highlight : 'Highlight', // MISSING
-		selected : 'Selected', // MISSING
-		clear : 'Clear' // MISSING
+		title		: 'Select color', // MISSING
+		options	:	'Color Options', // MISSING
+		highlight	: 'Highlight', // MISSING
+		selected	: 'Selected Color', // MISSING
+		clear		: 'Clear' // MISSING
 	},
 
-	toolbarCollapse : 'Collapse Toolbar', // MISSING
-	toolbarExpand : 'Expand Toolbar' // MISSING
+	toolbarCollapse	: 'Collapse Toolbar', // MISSING
+	toolbarExpand	: 'Expand Toolbar', // MISSING
+
+	toolbarGroups :
+	{
+		document : 'Document', // MISSING
+		clipboard : 'Clipboard/Undo', // MISSING
+		editing : 'Editing', // MISSING
+		forms : 'Forms', // MISSING
+		basicstyles : 'Basic Styles', // MISSING
+		paragraph : 'Paragraph', // MISSING
+		links : 'Links', // MISSING
+		insert : 'Insert', // MISSING
+		styles : 'Styles', // MISSING
+		colors : 'Colors', // MISSING
+		tools : 'Tools' // MISSING
+	},
+
+	bidi :
+	{
+		ltr : 'Text direction from left to right', // MISSING
+		rtl : 'Text direction from right to left' // MISSING
+	},
+
+	docprops :
+	{
+		label : 'ویژگیهای سند',
+		title : 'ویژگیهای سند',
+		design : 'Design', // MISSING
+		meta : 'فراداده',
+		chooseColor : 'Choose', // MISSING
+		other : '<سایر>',
+		docTitle :	'عنوان صفحه',
+		charset : 	'رمزگذاری نویسهگان',
+		charsetOther : 'رمزگذاری نویسهگان دیگر',
+		charsetASCII : 'ASCII', // MISSING
+		charsetCE : 'اروپای مرکزی',
+		charsetCT : 'چینی رسمی (Big5)',
+		charsetCR : 'سیریلیک',
+		charsetGR : 'یونانی',
+		charsetJP : 'ژاپنی',
+		charsetKR : 'کرهای',
+		charsetTR : 'ترکی',
+		charsetUN : 'یونیکُد (UTF-8)',
+		charsetWE : 'اروپای غربی',
+		docType : 'عنوان نوع سند',
+		docTypeOther : 'عنوان نوع سند دیگر',
+		xhtmlDec : 'شامل تعاریف XHTML',
+		bgColor : 'رنگ پسزمینه',
+		bgImage : 'URL تصویر پسزمینه',
+		bgFixed : 'پسزمینهٴ پیمایشناپذیر',
+		txtColor : 'رنگ متن',
+		margin : 'حاشیههای صفحه',
+		marginTop : 'بالا',
+		marginLeft : 'چپ',
+		marginRight : 'راست',
+		marginBottom : 'پایین',
+		metaKeywords : 'کلیدواژگان نمایهگذاری سند (با کاما جدا شوند)',
+		metaDescription : 'توصیف سند',
+		metaAuthor : 'نویسنده',
+		metaCopyright : 'کپیرایت',
+		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
+	}
 };
