@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -31,7 +31,11 @@ CKEDITOR.lang['hr'] =
 	 * Screenreader titles. Please note that screenreaders are not always capable
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle		: 'Text editor, %1',
+	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+
+	// ARIA descriptions.
+	toolbars	: 'Editor toolbars', // MISSING
+	editor		: 'Rich Text Editor', // MISSING
 
 	// Toolbar buttons without dialogs.
 	source			: 'Kôd',
@@ -52,6 +56,7 @@ CKEDITOR.lang['hr'] =
 	superscript		: 'Superscript',
 	horizontalrule	: 'Ubaci vodoravnu liniju',
 	pagebreak		: 'Ubaci prijelom stranice',
+	pagebreakAlt		: 'Page Break', // MISSING
 	unlink			: 'Ukloni link',
 	undo			: 'Poništi',
 	redo			: 'Ponovi',
@@ -68,12 +73,12 @@ CKEDITOR.lang['hr'] =
 		flash			: 'Flash',
 		form			: 'Form',
 		checkbox		: 'Checkbox',
-		radio		: 'Radio Button',
+		radio			: 'Radio Button',
 		textField		: 'Text Field',
 		textarea		: 'Textarea',
 		hiddenField		: 'Hidden Field',
 		button			: 'Button',
-		select	: 'Selection Field',
+		select			: 'Selection Field',
 		imageButton		: 'Image Button',
 		notSet			: '<nije postavljeno>',
 		id				: 'Id',
@@ -88,27 +93,59 @@ CKEDITOR.lang['hr'] =
 		cssStyle		: 'Stil',
 		ok				: 'OK',
 		cancel			: 'Poništi',
+		close			: 'Close', // MISSING
+		preview			: 'Preview', // MISSING
 		generalTab		: 'Općenito',
 		advancedTab		: 'Napredno',
-		validateNumberFailed	: 'Ova vrijednost nije broj.',
+		validateNumberFailed : 'Ova vrijednost nije broj.',
 		confirmNewPage	: 'Sve napravljene promjene će biti izgubljene ukoliko ih niste snimili. Sigurno želite učitati novu stranicu?',
 		confirmCancel	: 'Neke od opcija su promjenjene. Sigurno želite zatvoriti ovaj prozor?',
+		options			: 'Options', // MISSING
+		target			: 'Target', // MISSING
+		targetNew		: 'New Window (_blank)', // MISSING
+		targetTop		: 'Topmost Window (_top)', // MISSING
+		targetSelf		: 'Same Window (_self)', // MISSING
+		targetParent	: 'Parent Window (_parent)', // MISSING
+		langDirLTR		: 'Left to Right (LTR)', // MISSING
+		langDirRTL		: 'Right to Left (RTL)', // MISSING
+		styles			: 'Style', // MISSING
+		cssClasses		: 'Stylesheet Classes', // MISSING
+		width			: 'Širina',
+		height			: 'Visina',
+		align			: 'Poravnaj',
+		alignLeft		: 'Lijevo',
+		alignRight		: 'Desno',
+		alignCenter		: 'Središnje',
+		alignTop		: 'Vrh',
+		alignMiddle		: 'Sredina',
+		alignBottom		: 'Dolje',
+		invalidHeight	: 'Visina mora biti broj.',
+		invalidWidth	: 'Širina mora biti broj.',
+		invalidCssLength	: 'Value specified for the "%1" field must be a positive number with or without a valid CSS measurement unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
+		invalidHtmlLength	: 'Value specified for the "%1" field must be a positive number with or without a valid HTML measurement unit (px or %).', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, nedostupno</span>'
 	},
 
+	contextmenu :
+	{
+		options : 'Context Menu Options' // MISSING
+	},
+
 	// Special char dialog.
 	specialChar		:
 	{
 		toolbar		: 'Ubaci posebne znakove',
-		title		: 'Odaberite posebni karakter'
+		title		: 'Odaberite posebni karakter',
+		options : 'Special Character Options' // MISSING
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'Ubaci/promijeni link',
+		other 		: '<drugi>',
 		menu		: 'Promijeni link',
 		title		: 'Link',
 		info		: 'Link Info',
@@ -116,50 +153,43 @@ CKEDITOR.lang['hr'] =
 		upload		: 'Pošalji',
 		advanced	: 'Napredno',
 		type		: 'Link vrsta',
+		toUrl		: 'URL', // MISSING
 		toAnchor	: 'Sidro na ovoj stranici',
 		toEmail		: 'E-Mail',
-		target		: 'Meta',
-		targetNotSet	: '<nije postavljeno>',
-		targetFrame	: '<okvir>',
-		targetPopup	: '<popup prozor>',
-		targetNew	: 'Novi prozor (_blank)',
-		targetTop	: 'Vršni prozor (_top)',
-		targetSelf	: 'Isti prozor (_self)',
-		targetParent	: 'Roditeljski prozor (_parent)',
+		targetFrame		: '<okvir>',
+		targetPopup		: '<popup prozor>',
 		targetFrameName	: 'Ime ciljnog okvira',
 		targetPopupName	: 'Naziv popup prozora',
 		popupFeatures	: 'Mogućnosti popup prozora',
 		popupResizable	: 'Promjenjiva veličina',
 		popupStatusBar	: 'Statusna traka',
-		popupLocationBar	: 'Traka za lokaciju',
+		popupLocationBar: 'Traka za lokaciju',
 		popupToolbar	: 'Traka s alatima',
 		popupMenuBar	: 'Izborna traka',
 		popupFullScreen	: 'Cijeli ekran (IE)',
 		popupScrollBars	: 'Scroll traka',
 		popupDependent	: 'Ovisno (Netscape)',
-		popupWidth		: 'Širina',
 		popupLeft		: 'Lijeva pozicija',
-		popupHeight		: 'Visina',
 		popupTop		: 'Gornja pozicija',
 		id				: 'Id',
 		langDir			: 'Smjer jezika',
-		langDirNotSet	: '<nije postavljeno>',
 		langDirLTR		: 'S lijeva na desno (LTR)',
 		langDirRTL		: 'S desna na lijevo (RTL)',
 		acccessKey		: 'Pristupna tipka',
 		name			: 'Naziv',
-		langCode		: 'Smjer jezika',
-		tabIndex		: 'Tab Indeks',
-		advisoryTitle	: 'Advisory naslov',
+		langCode			: 'Smjer jezika',
+		tabIndex			: 'Tab Indeks',
+		advisoryTitle		: 'Advisory naslov',
 		advisoryContentType	: 'Advisory vrsta sadržaja',
 		cssClasses		: 'Stylesheet klase',
 		charset			: 'Kodna stranica povezanih resursa',
 		styles			: 'Stil',
-		selectAnchor	: 'Odaberi sidro',
+		rel			: 'Relationship', // MISSING
+		selectAnchor		: 'Odaberi sidro',
 		anchorName		: 'Po nazivu sidra',
-		anchorId		: 'Po Id elementa',
-		emailAddress	: 'E-Mail adresa',
-		emailSubject	: 'Naslov',
+		anchorId			: 'Po Id elementa',
+		emailAddress		: 'E-Mail adresa',
+		emailSubject		: 'Naslov',
 		emailBody		: 'Sadržaj poruke',
 		noAnchors		: '(Nema dostupnih sidra)',
 		noUrl			: 'Molimo upišite URL link',
@@ -173,7 +203,32 @@ CKEDITOR.lang['hr'] =
 		menu		: 'Svojstva sidra',
 		title		: 'Svojstva sidra',
 		name		: 'Ime sidra',
-		errorName	: 'Molimo unesite ime sidra'
+		errorName	: 'Molimo unesite ime sidra',
+		remove		: 'Remove Anchor' // MISSING
+	},
+
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'Numbered List Properties', // MISSING
+		bulletedTitle		: 'Bulleted List Properties', // MISSING
+		type				: 'Type', // MISSING
+		start				: 'Start', // MISSING
+		validateStartNumber				:'List start number must be a whole number.', // MISSING
+		circle				: 'Circle', // MISSING
+		disc				: 'Disc', // MISSING
+		square				: 'Square', // MISSING
+		none				: 'None', // MISSING
+		notset				: '<not set>', // MISSING
+		armenian			: 'Armenian numbering', // MISSING
+		georgian			: 'Georgian numbering (an, ban, gan, etc.)', // MISSING
+		lowerRoman			: 'Lower Roman (i, ii, iii, iv, v, etc.)', // MISSING
+		upperRoman			: 'Upper Roman (I, II, III, IV, V, etc.)', // MISSING
+		lowerAlpha			: 'Lower Alpha (a, b, c, d, e, etc.)', // MISSING
+		upperAlpha			: 'Upper Alpha (A, B, C, D, E, etc.)', // MISSING
+		lowerGreek			: 'Lower Greek (alpha, beta, gamma, etc.)', // MISSING
+		decimal				: 'Decimal (1, 2, 3, etc.)', // MISSING
+		decimalLeadingZero	: 'Decimal leading zero (01, 02, 03, etc.)' // MISSING
 	},
 
 	// Find And Replace Dialog
@@ -202,15 +257,9 @@ CKEDITOR.lang['hr'] =
 		rows		: 'Redova',
 		columns		: 'Kolona',
 		border		: 'Veličina okvira',
-		align		: 'Poravnanje',
-		alignNotSet	: '<nije postavljeno>',
-		alignLeft	: 'Lijevo',
-		alignCenter	: 'Središnje',
-		alignRight	: 'Desno',
-		width		: 'Širina',
 		widthPx		: 'piksela',
 		widthPc		: 'postotaka',
-		height		: 'Visina',
+		widthUnit	: 'width unit', // MISSING
 		cellSpace	: 'Prostornost ćelija',
 		cellPad		: 'Razmak ćelija',
 		caption		: 'Naslov',
@@ -246,9 +295,6 @@ CKEDITOR.lang['hr'] =
 			wordWrap		: 'Prelazak u novi red',
 			hAlign			: 'Vodoravno poravnanje',
 			vAlign			: 'Okomito poravnanje',
-			alignTop		: 'Vrh',
-			alignMiddle		: 'Sredina',
-			alignBottom		: 'Dolje',
 			alignBaseline	: 'Osnovna linija',
 			bgColor			: 'Boja pozadine',
 			borderColor		: 'Boja ruba',
@@ -260,7 +306,7 @@ CKEDITOR.lang['hr'] =
 			invalidHeight	: 'Visina ćelije mora biti broj.',
 			invalidRowSpan	: 'Rows span mora biti cijeli broj.',
 			invalidColSpan	: 'Columns span mora biti cijeli broj.',
-			chooseColor : 'Choose' // MISSING
+			chooseColor		: 'Choose' // MISSING
 		},
 
 		row :
@@ -307,13 +353,7 @@ CKEDITOR.lang['hr'] =
 		menu		: 'Form svojstva',
 		action		: 'Akcija',
 		method		: 'Metoda',
-		encoding	: 'Encoding',
-		target		: 'Meta',
-		targetNotSet	: '<nije postavljeno>',
-		targetNew	: 'Novi prozor (_blank)',
-		targetTop	: 'Vršni prozor (_top)',
-		targetSelf	: 'Isti prozor (_self)',
-		targetParent	: 'Roditeljski prozor (_parent)'
+		encoding	: 'Encoding'
 	},
 
 	// Select Field Dialog.
@@ -371,27 +411,23 @@ CKEDITOR.lang['hr'] =
 		title		: 'Svojstva slika',
 		titleButton	: 'Image Button svojstva',
 		menu		: 'Svojstva slika',
-		infoTab	: 'Info slike',
+		infoTab		: 'Info slike',
 		btnUpload	: 'Pošalji na server',
-		url		: 'URL',
-		upload	: 'Pošalji',
-		alt		: 'Alternativni tekst',
-		width		: 'Širina',
-		height	: 'Visina',
+		upload		: 'Pošalji',
+		alt			: 'Alternativni tekst',
 		lockRatio	: 'Zaključaj odnos',
 		resetSize	: 'Obriši veličinu',
-		border	: 'Okvir',
-		hSpace	: 'HSpace',
-		vSpace	: 'VSpace',
-		align		: 'Poravnaj',
-		alignLeft	: 'Lijevo',
-		alignRight	: 'Desno',
-		preview	: 'Pregledaj',
+		border		: 'Okvir',
+		hSpace		: 'HSpace',
+		vSpace		: 'VSpace',
 		alertUrl	: 'Unesite URL slike',
-		linkTab	: 'Link',
+		linkTab		: 'Link',
 		button2Img	: 'Želite li promijeniti odabrani gumb u jednostavnu sliku?',
 		img2Button	: 'Želite li promijeniti odabranu sliku u gumb?',
-		urlMissing : 'Image source URL is missing.' // MISSING
+		urlMissing	: 'Image source URL is missing.', // MISSING
+		validateBorder	: 'Border must be a whole number.', // MISSING
+		validateHSpace	: 'HSpace must be a whole number.', // MISSING
+		validateVSpace	: 'VSpace must be a whole number.' // MISSING
 	},
 
 	// Flash Dialog
@@ -399,51 +435,41 @@ CKEDITOR.lang['hr'] =
 	{
 		properties		: 'Flash svojstva',
 		propertiesTab	: 'Svojstva',
-		title		: 'Flash svojstva',
-		chkPlay		: 'Auto Play',
-		chkLoop		: 'Ponavljaj',
-		chkMenu		: 'Omogući Flash izbornik',
-		chkFull		: 'Omogući Fullscreen',
- 		scale		: 'Omjer',
+		title			: 'Flash svojstva',
+		chkPlay			: 'Auto Play',
+		chkLoop			: 'Ponavljaj',
+		chkMenu			: 'Omogući Flash izbornik',
+		chkFull			: 'Omogući Fullscreen',
+ 		scale			: 'Omjer',
 		scaleAll		: 'Prikaži sve',
 		scaleNoBorder	: 'Bez okvira',
 		scaleFit		: 'Točna veličina',
 		access			: 'Script Access',
 		accessAlways	: 'Uvijek',
-		accessSameDomain	: 'Ista domena',
-		accessNever	: 'Nikad',
-		align		: 'Poravnaj',
-		alignLeft	: 'Lijevo',
-		alignAbsBottom: 'Abs dolje',
-		alignAbsMiddle: 'Abs sredina',
+		accessSameDomain: 'Ista domena',
+		accessNever		: 'Nikad',
+		alignAbsBottom	: 'Abs dolje',
+		alignAbsMiddle	: 'Abs sredina',
 		alignBaseline	: 'Bazno',
-		alignBottom	: 'Dolje',
-		alignMiddle	: 'Sredina',
-		alignRight	: 'Desno',
 		alignTextTop	: 'Vrh teksta',
-		alignTop	: 'Vrh',
-		quality		: 'Kvaliteta',
-		qualityBest		 : 'Best',
-		qualityHigh		 : 'High',
-		qualityAutoHigh	 : 'Auto High',
-		qualityMedium	 : 'Medium',
-		qualityAutoLow	 : 'Auto Low',
-		qualityLow		 : 'Low',
-		windowModeWindow	 : 'Window',
-		windowModeOpaque	 : 'Opaque',
-		windowModeTransparent	 : 'Transparent',
-		windowMode	: 'Vrsta prozora',
-		flashvars	: 'Varijable za Flash',
-		bgcolor	: 'Boja pozadine',
-		width	: 'Širina',
-		height	: 'Visina',
-		hSpace	: 'HSpace',
-		vSpace	: 'VSpace',
-		validateSrc : 'Molimo upišite URL link',
-		validateWidth : 'Širina mora biti broj.',
-		validateHeight : 'Visina mora biti broj.',
-		validateHSpace : 'HSpace mora biti broj.',
-		validateVSpace : 'VSpace mora biti broj.'
+		quality			: 'Kvaliteta',
+		qualityBest		: 'Best',
+		qualityHigh		: 'High',
+		qualityAutoHigh	: 'Auto High',
+		qualityMedium	: 'Medium',
+		qualityAutoLow	: 'Auto Low',
+		qualityLow		: 'Low',
+		windowModeWindow: 'Window',
+		windowModeOpaque: 'Opaque',
+		windowModeTransparent : 'Transparent',
+		windowMode		: 'Vrsta prozora',
+		flashvars		: 'Varijable za Flash',
+		bgcolor			: 'Boja pozadine',
+		hSpace			: 'HSpace',
+		vSpace			: 'VSpace',
+		validateSrc		: 'Molimo upišite URL link',
+		validateHSpace	: 'HSpace mora biti broj.',
+		validateVSpace	: 'VSpace mora biti broj.'
 	},
 
 	// Speller Pages Dialog
@@ -472,25 +498,27 @@ CKEDITOR.lang['hr'] =
 	smiley :
 	{
 		toolbar	: 'Smješko',
-		title	: 'Ubaci smješka'
+		title	: 'Ubaci smješka',
+		options : 'Smiley Options' // MISSING
 	},
 
 	elementsPath :
 	{
+		eleLabel : 'Elements path', // MISSING
 		eleTitle : '%1 element'
 	},
 
-	numberedlist : 'Brojčana lista',
-	bulletedlist : 'Obična lista',
-	indent : 'Pomakni udesno',
-	outdent : 'Pomakni ulijevo',
+	numberedlist	: 'Brojčana lista',
+	bulletedlist	: 'Obična lista',
+	indent			: 'Pomakni udesno',
+	outdent			: 'Pomakni ulijevo',
 
 	justify :
 	{
-		left : 'Lijevo poravnanje',
-		center : 'Središnje poravnanje',
-		right : 'Desno poravnanje',
-		block : 'Blok poravnanje'
+		left	: 'Lijevo poravnanje',
+		center	: 'Središnje poravnanje',
+		right	: 'Desno poravnanje',
+		block	: 'Blok poravnanje'
 	},
 
 	blockquote : 'Blockquote',
@@ -498,64 +526,63 @@ CKEDITOR.lang['hr'] =
 	clipboard :
 	{
 		title		: 'Zalijepi',
-		cutError	: 'Sigurnosne postavke Vašeg pretraživača ne dozvoljavaju operacije automatskog izrezivanja. Molimo koristite kraticu na tipkovnici (Ctrl+X).',
-		copyError	: 'Sigurnosne postavke Vašeg pretraživača ne dozvoljavaju operacije automatskog kopiranja. Molimo koristite kraticu na tipkovnici (Ctrl+C).',
-		pasteMsg	: 'Molimo zaljepite unutar doljnjeg okvira koristeći tipkovnicu (<STRONG>Ctrl+V</STRONG>) i kliknite <STRONG>OK</STRONG>.',
-		securityMsg	: 'Zbog sigurnosnih postavki Vašeg pretraživača, editor nema direktan pristup Vašem međuspremniku. Potrebno je ponovno zalijepiti tekst u ovaj prozor.'
+		cutError	: 'Sigurnosne postavke Vašeg pretraživača ne dozvoljavaju operacije automatskog izrezivanja. Molimo koristite kraticu na tipkovnici (Ctrl/Cmd+X).',
+		copyError	: 'Sigurnosne postavke Vašeg pretraživača ne dozvoljavaju operacije automatskog kopiranja. Molimo koristite kraticu na tipkovnici (Ctrl/Cmd+C).',
+		pasteMsg	: 'Molimo zaljepite unutar doljnjeg okvira koristeći tipkovnicu (<STRONG>Ctrl/Cmd+V</STRONG>) i kliknite <STRONG>OK</STRONG>.',
+		securityMsg	: 'Zbog sigurnosnih postavki Vašeg pretraživača, editor nema direktan pristup Vašem međuspremniku. Potrebno je ponovno zalijepiti tekst u ovaj prozor.',
+		pasteArea	: 'Paste Area' // MISSING
 	},
 
 	pastefromword :
 	{
-		confirmCleanup : 'Tekst koji želite zalijepiti čini se da je kopiran iz Worda. Želite li prije očistiti tekst?',
-		toolbar : 'Zalijepi iz Worda',
-		title : 'Zalijepi iz Worda',
-		error : 'It was not possible to clean up the pasted data due to an internal error' // MISSING
+		confirmCleanup	: 'Tekst koji želite zalijepiti čini se da je kopiran iz Worda. Želite li prije očistiti tekst?',
+		toolbar			: 'Zalijepi iz Worda',
+		title			: 'Zalijepi iz Worda',
+		error			: 'It was not possible to clean up the pasted data due to an internal error' // MISSING
 	},
 
 	pasteText :
 	{
-		button : 'Zalijepi kao čisti tekst',
-		title : 'Zalijepi kao čisti tekst'
+		button	: 'Zalijepi kao čisti tekst',
+		title	: 'Zalijepi kao čisti tekst'
 	},
 
 	templates :
 	{
-		button : 'Predlošci',
-		title : 'Predlošci sadržaja',
-		insertOption: 'Zamijeni trenutne sadržaje',
-		selectPromptMsg: 'Molimo odaberite predložak koji želite otvoriti<br>(stvarni sadržaj će biti izgubljen):',
-		emptyListMsg : '(Nema definiranih predložaka)'
+		button			: 'Predlošci',
+		title			: 'Predlošci sadržaja',
+		options : 'Template Options', // MISSING
+		insertOption	: 'Zamijeni trenutne sadržaje',
+		selectPromptMsg	: 'Molimo odaberite predložak koji želite otvoriti<br>(stvarni sadržaj će biti izgubljen):',
+		emptyListMsg	: '(Nema definiranih predložaka)'
 	},
 
 	showBlocks : 'Prikaži blokove',
 
 	stylesCombo :
 	{
-		label : 'Stil',
-		voiceLabel : 'Stilovi',
-		panelVoiceLabel : 'Odaberite stil',
-		panelTitle1 : 'Block stilovi',
-		panelTitle2 : 'Inline stilovi',
-		panelTitle3 : 'Object stilovi'
+		label		: 'Stil',
+		panelTitle	: 'Formatting Styles', // MISSING
+		panelTitle1	: 'Block stilovi',
+		panelTitle2	: 'Inline stilovi',
+		panelTitle3	: 'Object stilovi'
 	},
 
 	format :
 	{
-		label : 'Format',
-		voiceLabel : 'Format',
-		panelTitle : 'Format',
-		panelVoiceLabel : 'Odaberite format paragrafa',
+		label		: 'Format',
+		panelTitle	: 'Format',
 
-		tag_p : 'Normal',
-		tag_pre : 'Formatirano',
-		tag_address : 'Address',
-		tag_h1 : 'Heading 1',
-		tag_h2 : 'Heading 2',
-		tag_h3 : 'Heading 3',
-		tag_h4 : 'Heading 4',
-		tag_h5 : 'Heading 5',
-		tag_h6 : 'Heading 6',
-		tag_div : 'Normal (DIV)'
+		tag_p		: 'Normal',
+		tag_pre		: 'Formatirano',
+		tag_address	: 'Address',
+		tag_h1		: 'Heading 1',
+		tag_h2		: 'Heading 2',
+		tag_h3		: 'Heading 3',
+		tag_h4		: 'Heading 4',
+		tag_h5		: 'Heading 5',
+		tag_h6		: 'Heading 6',
+		tag_div		: 'Normal (DIV)'
 	},
 
 	div :
@@ -575,28 +602,36 @@ CKEDITOR.lang['hr'] =
 		remove				: 'Remove Div' // MISSING
   	},
 
+	iframe :
+	{
+		title		: 'IFrame Properties', // MISSING
+		toolbar		: 'IFrame', // MISSING
+		noUrl		: 'Please type the iframe URL', // MISSING
+		scrolling	: 'Enable scrollbars', // MISSING
+		border		: 'Show frame border' // MISSING
+	},
+
 	font :
 	{
-		label : 'Font',
-		voiceLabel : 'Font',
-		panelTitle : 'Font',
-		panelVoiceLabel : 'Odaberite font'
+		label		: 'Font',
+		voiceLabel	: 'Font',
+		panelTitle	: 'Font'
 	},
 
 	fontSize :
 	{
-		label : 'Veličina',
-		voiceLabel : 'Veličina slova',
-		panelTitle : 'Veličina',
-		panelVoiceLabel : 'Odaberite veličinu slova'
+		label		: 'Veličina',
+		voiceLabel	: 'Veličina slova',
+		panelTitle	: 'Veličina'
 	},
 
 	colorButton :
 	{
-		textColorTitle : 'Boja teksta',
-		bgColorTitle : 'Boja pozadine',
-		auto : 'Automatski',
-		more : 'Više boja...'
+		textColorTitle	: 'Boja teksta',
+		bgColorTitle	: 'Boja pozadine',
+		panelTitle		: 'Colors', // MISSING
+		auto			: 'Automatski',
+		more			: 'Više boja...'
 	},
 
 	colors :
@@ -608,7 +643,7 @@ CKEDITOR.lang['hr'] =
 		'008080' : 'Teal', // MISSING
 		'000080' : 'Navy', // MISSING
 		'4B0082' : 'Indigo', // MISSING
-		'696969' : 'Dim Gray', // MISSING
+		'696969' : 'Dark Gray', // MISSING
 		'B22222' : 'Fire Brick', // MISSING
 		'A52A2A' : 'Brown', // MISSING
 		'DAA520' : 'Golden Rod', // MISSING
@@ -624,7 +659,7 @@ CKEDITOR.lang['hr'] =
 		'0FF' : 'Cyan', // MISSING
 		'00F' : 'Blue', // MISSING
 		'EE82EE' : 'Violet', // MISSING
-		'A9A9A9' : 'Dark Gray', // MISSING
+		'A9A9A9' : 'Dim Gray', // MISSING
 		'FFA07A' : 'Light Salmon', // MISSING
 		'FFA500' : 'Orange', // MISSING
 		'FFFF00' : 'Yellow', // MISSING
@@ -645,30 +680,47 @@ CKEDITOR.lang['hr'] =
 
 	scayt :
 	{
-		title : 'Provjeri pravopis tijekom tipkanja (SCAYT)',
-		enable : 'Omogući SCAYT',
-		disable : 'Onemogući SCAYT',
-		about : 'O SCAYT',
-		toggle : 'Omoguću/Onemogući SCAYT',
-		options : 'Opcije',
-		langs : 'Jezici',
-		moreSuggestions : 'Više prijedloga',
-		ignore : 'Zanemari',
-		ignoreAll : 'Zanemari sve',
-		addWord : 'Dodaj riječ',
-		emptyDic : 'Naziv rječnika ne smije biti prazno.',
-		optionsTab : 'Opcije',
-		languagesTab : 'Jezici',
-		dictionariesTab : 'Rječnici',
-		aboutTab : 'O SCAYT'
+		title			: 'Provjeri pravopis tijekom tipkanja (SCAYT)',
+		opera_title		: 'Not supported by Opera', // MISSING
+		enable			: 'Omogući SCAYT',
+		disable			: 'Onemogući SCAYT',
+		about			: 'O SCAYT',
+		toggle			: 'Omoguću/Onemogući SCAYT',
+		options			: 'Opcije',
+		langs			: 'Jezici',
+		moreSuggestions	: 'Više prijedloga',
+		ignore			: 'Zanemari',
+		ignoreAll		: 'Zanemari sve',
+		addWord			: 'Dodaj riječ',
+		emptyDic		: 'Naziv rječnika ne smije biti prazno.',
+
+		optionsTab		: 'Opcije',
+		allCaps			: 'Ignore All-Caps Words', // MISSING
+		ignoreDomainNames : 'Ignore Domain Names', // MISSING
+		mixedCase		: 'Ignore Words with Mixed Case', // MISSING
+		mixedWithDigits	: 'Ignore Words with Numbers', // MISSING
+
+		languagesTab	: 'Jezici',
+
+		dictionariesTab	: 'Rječnici',
+		dic_field_name	: 'Dictionary name', // MISSING
+		dic_create		: 'Create', // MISSING
+		dic_restore		: 'Restore', // MISSING
+		dic_delete		: 'Delete', // MISSING
+		dic_rename		: 'Rename', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type its name and click the Restore button.', // MISSING
+
+		aboutTab		: 'O SCAYT'
 	},
 
 	about :
 	{
-		title : 'O CKEditoru',
-		dlgTitle : 'O CKEditoru',
-		moreInfo : 'Za informacije o licencama posjetite našu web stranicu:',
-		copy : 'Copyright &copy; $1. All rights reserved.'
+		title		: 'O CKEditoru',
+		dlgTitle	: 'O CKEditoru',
+		help	: 'Check $1 for help.', // MISSING
+		userGuide : 'CKEditor User\'s Guide', // MISSING
+		moreInfo	: 'Za informacije o licencama posjetite našu web stranicu:',
+		copy		: 'Copyright &copy; $1. All rights reserved.'
 	},
 
 	maximize : 'Povećaj',
@@ -676,22 +728,85 @@ CKEDITOR.lang['hr'] =
 
 	fakeobjects :
 	{
-		anchor : 'Sidro',
-		flash : 'Flash animacija',
-		div : 'Prijelom stranice',
-		unknown : 'Nepoznati objekt'
+		anchor		: 'Sidro',
+		flash		: 'Flash animacija',
+		iframe		: 'IFrame', // MISSING
+		hiddenfield	: 'Hidden Field', // MISSING
+		unknown		: 'Nepoznati objekt'
 	},
 
 	resize : 'Povuci za promjenu veličine',
 
 	colordialog :
 	{
-		title : 'Select color', // MISSING
-		highlight : 'Highlight', // MISSING
-		selected : 'Selected', // MISSING
-		clear : 'Clear' // MISSING
+		title		: 'Select color', // MISSING
+		options	:	'Color Options', // MISSING
+		highlight	: 'Highlight', // MISSING
+		selected	: 'Selected Color', // MISSING
+		clear		: 'Clear' // MISSING
 	},
 
-	toolbarCollapse : 'Collapse Toolbar', // MISSING
-	toolbarExpand : 'Expand Toolbar' // MISSING
+	toolbarCollapse	: 'Collapse Toolbar', // MISSING
+	toolbarExpand	: 'Expand Toolbar', // MISSING
+
+	toolbarGroups :
+	{
+		document : 'Document', // MISSING
+		clipboard : 'Clipboard/Undo', // MISSING
+		editing : 'Editing', // MISSING
+		forms : 'Forms', // MISSING
+		basicstyles : 'Basic Styles', // MISSING
+		paragraph : 'Paragraph', // MISSING
+		links : 'Links', // MISSING
+		insert : 'Insert', // MISSING
+		styles : 'Styles', // MISSING
+		colors : 'Colors', // MISSING
+		tools : 'Tools' // MISSING
+	},
+
+	bidi :
+	{
+		ltr : 'Text direction from left to right', // MISSING
+		rtl : 'Text direction from right to left' // MISSING
+	},
+
+	docprops :
+	{
+		label : 'Svojstva dokumenta',
+		title : 'Svojstva dokumenta',
+		design : 'Design', // MISSING
+		meta : 'Meta Data',
+		chooseColor : 'Choose', // MISSING
+		other : '<drugi>',
+		docTitle :	'Naslov stranice',
+		charset : 	'Enkodiranje znakova',
+		charsetOther : 'Ostalo enkodiranje znakova',
+		charsetASCII : 'ASCII', // MISSING
+		charsetCE : 'Središnja Europa',
+		charsetCT : 'Tradicionalna kineska (Big5)',
+		charsetCR : 'Ćirilica',
+		charsetGR : 'Grčka',
+		charsetJP : 'Japanska',
+		charsetKR : 'Koreanska',
+		charsetTR : 'Turska',
+		charsetUN : 'Unicode (UTF-8)', // MISSING
+		charsetWE : 'Zapadna Europa',
+		docType : 'Zaglavlje vrste dokumenta',
+		docTypeOther : 'Ostalo zaglavlje vrste dokumenta',
+		xhtmlDec : 'Ubaci XHTML deklaracije',
+		bgColor : 'Boja pozadine',
+		bgImage : 'URL slike pozadine',
+		bgFixed : 'Pozadine se ne pomiče',
+		txtColor : 'Boja teksta',
+		margin : 'Margine stranice',
+		marginTop : 'Vrh',
+		marginLeft : 'Lijevo',
+		marginRight : 'Desno',
+		marginBottom : 'Dolje',
+		metaKeywords : 'Ključne riječi dokumenta (odvojene zarezom)',
+		metaDescription : 'Opis dokumenta',
+		metaAuthor : 'Autor',
+		metaCopyright : 'Autorska prava',
+		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
+	}
 };
