@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -34,8 +34,8 @@ CKEDITOR.lang['ms'] =
 	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
 
 	// ARIA descriptions.
-	toolbar	: 'Toolbar', // MISSING
-	editor	: 'Rich Text Editor', // MISSING
+	toolbars	: 'Editor toolbars', // MISSING
+	editor		: 'Rich Text Editor', // MISSING
 
 	// Toolbar buttons without dialogs.
 	source			: 'Sumber',
@@ -56,6 +56,7 @@ CKEDITOR.lang['ms'] =
 	superscript		: 'Superscript',
 	horizontalrule	: 'Masukkan Garisan Membujur',
 	pagebreak		: 'Insert Page Break for Printing', // MISSING
+	pagebreakAlt		: 'Page Break', // MISSING
 	unlink			: 'Buang Sambungan',
 	undo			: 'Batalkan',
 	redo			: 'Ulangkan',
@@ -105,6 +106,23 @@ CKEDITOR.lang['ms'] =
 		targetTop		: 'Topmost Window (_top)', // MISSING
 		targetSelf		: 'Same Window (_self)', // MISSING
 		targetParent	: 'Parent Window (_parent)', // MISSING
+		langDirLTR		: 'Left to Right (LTR)', // MISSING
+		langDirRTL		: 'Right to Left (RTL)', // MISSING
+		styles			: 'Style', // MISSING
+		cssClasses		: 'Stylesheet Classes', // MISSING
+		width			: 'Lebar',
+		height			: 'Tinggi',
+		align			: 'Jajaran',
+		alignLeft		: 'Kiri',
+		alignRight		: 'Kanan',
+		alignCenter		: 'Tengah',
+		alignTop		: 'Atas',
+		alignMiddle		: 'Pertengahan',
+		alignBottom		: 'Bawah',
+		invalidHeight	: 'Height must be a number.', // MISSING
+		invalidWidth	: 'Width must be a number.', // MISSING
+		invalidCssLength	: 'Value specified for the "%1" field must be a positive number with or without a valid CSS measurement unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
+		invalidHtmlLength	: 'Value specified for the "%1" field must be a positive number with or without a valid HTML measurement unit (px or %).', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, unavailable</span>' // MISSING
@@ -151,9 +169,7 @@ CKEDITOR.lang['ms'] =
 		popupFullScreen	: 'Skrin Penuh (IE)',
 		popupScrollBars	: 'Bar-bar skrol',
 		popupDependent	: 'Bergantungan (Netscape)',
-		popupWidth		: 'Lebar',
 		popupLeft		: 'Posisi Kiri',
-		popupHeight		: 'Tinggi',
 		popupTop		: 'Posisi Atas',
 		id				: 'Id', // MISSING
 		langDir			: 'Arah Tulisan',
@@ -161,18 +177,19 @@ CKEDITOR.lang['ms'] =
 		langDirRTL		: 'Kanan ke Kiri (RTL)',
 		acccessKey		: 'Kunci Akses',
 		name			: 'Nama',
-		langCode		: 'Arah Tulisan',
-		tabIndex		: 'Indeks Tab ',
-		advisoryTitle	: 'Tajuk Makluman',
+		langCode			: 'Arah Tulisan',
+		tabIndex			: 'Indeks Tab ',
+		advisoryTitle		: 'Tajuk Makluman',
 		advisoryContentType	: 'Jenis Kandungan Makluman',
 		cssClasses		: 'Kelas-kelas Stylesheet',
 		charset			: 'Linked Resource Charset',
 		styles			: 'Stail',
-		selectAnchor	: 'Sila pilih pautan',
+		rel			: 'Relationship', // MISSING
+		selectAnchor		: 'Sila pilih pautan',
 		anchorName		: 'dengan menggunakan nama pautan',
-		anchorId		: 'dengan menggunakan ID elemen',
-		emailAddress	: 'Alamat E-Mail',
-		emailSubject	: 'Subjek Mesej',
+		anchorId			: 'dengan menggunakan ID elemen',
+		emailAddress		: 'Alamat E-Mail',
+		emailSubject		: 'Subjek Mesej',
 		emailBody		: 'Isi Kandungan Mesej',
 		noAnchors		: '(Tiada pautan terdapat dalam dokumen ini)',
 		noUrl			: 'Sila taip sambungan URL',
@@ -186,7 +203,8 @@ CKEDITOR.lang['ms'] =
 		menu		: 'Ciri-ciri Pautan',
 		title		: 'Ciri-ciri Pautan',
 		name		: 'Nama Pautan',
-		errorName	: 'Sila taip nama pautan'
+		errorName	: 'Sila taip nama pautan',
+		remove		: 'Remove Anchor' // MISSING
 	},
 
 	// List style dialog
@@ -196,6 +214,7 @@ CKEDITOR.lang['ms'] =
 		bulletedTitle		: 'Bulleted List Properties', // MISSING
 		type				: 'Type', // MISSING
 		start				: 'Start', // MISSING
+		validateStartNumber				:'List start number must be a whole number.', // MISSING
 		circle				: 'Circle', // MISSING
 		disc				: 'Disc', // MISSING
 		square				: 'Square', // MISSING
@@ -238,15 +257,9 @@ CKEDITOR.lang['ms'] =
 		rows		: 'Barisan',
 		columns		: 'Jaluran',
 		border		: 'Saiz Border',
-		align		: 'Penjajaran',
-		alignLeft	: 'Kiri',
-		alignCenter	: 'Tengah',
-		alignRight	: 'Kanan',
-		width		: 'Lebar',
 		widthPx		: 'piksel-piksel',
 		widthPc		: 'peratus',
 		widthUnit	: 'width unit', // MISSING
-		height		: 'Tinggi',
 		cellSpace	: 'Ruangan Antara Sel',
 		cellPad		: 'Tambahan Ruang Sel',
 		caption		: 'Keterangan',
@@ -261,8 +274,8 @@ CKEDITOR.lang['ms'] =
 		invalidBorder	: 'Border size must be a number.', // MISSING
 		invalidWidth	: 'Table width must be a number.', // MISSING
 		invalidHeight	: 'Table height must be a number.', // MISSING
-		invalidCellSpacing	: 'Cell spacing must be a number.', // MISSING
-		invalidCellPadding	: 'Cell padding must be a number.', // MISSING
+		invalidCellSpacing	: 'Cell spacing must be a positive number.', // MISSING
+		invalidCellPadding	: 'Cell padding must be a positive number.', // MISSING
 
 		cell :
 		{
@@ -282,9 +295,6 @@ CKEDITOR.lang['ms'] =
 			wordWrap		: 'Word Wrap', // MISSING
 			hAlign			: 'Horizontal Alignment', // MISSING
 			vAlign			: 'Vertical Alignment', // MISSING
-			alignTop		: 'Top', // MISSING
-			alignMiddle		: 'Middle', // MISSING
-			alignBottom		: 'Bottom', // MISSING
 			alignBaseline	: 'Baseline', // MISSING
 			bgColor			: 'Background Color', // MISSING
 			borderColor		: 'Border Color', // MISSING
@@ -405,24 +415,16 @@ CKEDITOR.lang['ms'] =
 		btnUpload	: 'Hantar ke Server',
 		upload		: 'Muat Naik',
 		alt			: 'Text Alternatif',
-		width		: 'Lebar',
-		height		: 'Tinggi',
 		lockRatio	: 'Tetapkan Nisbah',
-		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Saiz Set Semula',
 		border		: 'Border',
 		hSpace		: 'Ruang Melintang',
 		vSpace		: 'Ruang Menegak',
-		align		: 'Jajaran',
-		alignLeft	: 'Kiri',
-		alignRight	: 'Kanan',
 		alertUrl	: 'Sila taip URL untuk fail gambar',
 		linkTab		: 'Sambungan',
 		button2Img	: 'Do you want to transform the selected image button on a simple image?', // MISSING
 		img2Button	: 'Do you want to transform the selected image on a image button?', // MISSING
 		urlMissing	: 'Image source URL is missing.', // MISSING
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
 		validateBorder	: 'Border must be a whole number.', // MISSING
 		validateHSpace	: 'HSpace must be a whole number.', // MISSING
 		validateVSpace	: 'VSpace must be a whole number.' // MISSING
@@ -446,16 +448,10 @@ CKEDITOR.lang['ms'] =
 		accessAlways	: 'Always', // MISSING
 		accessSameDomain: 'Same domain', // MISSING
 		accessNever		: 'Never', // MISSING
-		align			: 'Jajaran',
-		alignLeft		: 'Kiri',
 		alignAbsBottom	: 'Bawah Mutlak',
 		alignAbsMiddle	: 'Pertengahan Mutlak',
 		alignBaseline	: 'Garis Dasar',
-		alignBottom		: 'Bawah',
-		alignMiddle		: 'Pertengahan',
-		alignRight		: 'Kanan',
 		alignTextTop	: 'Atas Text',
-		alignTop		: 'Atas',
 		quality			: 'Quality', // MISSING
 		qualityBest		: 'Best', // MISSING
 		qualityHigh		: 'High', // MISSING
@@ -469,13 +465,9 @@ CKEDITOR.lang['ms'] =
 		windowMode		: 'Window mode', // MISSING
 		flashvars		: 'Variables for Flash', // MISSING
 		bgcolor			: 'Warna Latarbelakang',
-		width			: 'Lebar',
-		height			: 'Tinggi',
 		hSpace			: 'Ruang Melintang',
 		vSpace			: 'Ruang Menegak',
 		validateSrc		: 'Sila taip sambungan URL',
-		validateWidth	: 'Width must be a number.', // MISSING
-		validateHeight	: 'Height must be a number.', // MISSING
 		validateHSpace	: 'HSpace must be a number.', // MISSING
 		validateVSpace	: 'VSpace must be a number.' // MISSING
 	},
@@ -610,6 +602,15 @@ CKEDITOR.lang['ms'] =
 		remove				: 'Remove Div' // MISSING
   	},
 
+	iframe :
+	{
+		title		: 'IFrame Properties', // MISSING
+		toolbar		: 'IFrame', // MISSING
+		noUrl		: 'Please type the iframe URL', // MISSING
+		scrolling	: 'Enable scrollbars', // MISSING
+		border		: 'Show frame border' // MISSING
+	},
+
 	font :
 	{
 		label		: 'Font',
@@ -642,7 +643,7 @@ CKEDITOR.lang['ms'] =
 		'008080' : 'Teal', // MISSING
 		'000080' : 'Navy', // MISSING
 		'4B0082' : 'Indigo', // MISSING
-		'696969' : 'Dim Gray', // MISSING
+		'696969' : 'Dark Gray', // MISSING
 		'B22222' : 'Fire Brick', // MISSING
 		'A52A2A' : 'Brown', // MISSING
 		'DAA520' : 'Golden Rod', // MISSING
@@ -658,7 +659,7 @@ CKEDITOR.lang['ms'] =
 		'0FF' : 'Cyan', // MISSING
 		'00F' : 'Blue', // MISSING
 		'EE82EE' : 'Violet', // MISSING
-		'A9A9A9' : 'Dark Gray', // MISSING
+		'A9A9A9' : 'Dim Gray', // MISSING
 		'FFA07A' : 'Light Salmon', // MISSING
 		'FFA500' : 'Orange', // MISSING
 		'FFFF00' : 'Yellow', // MISSING
@@ -707,7 +708,7 @@ CKEDITOR.lang['ms'] =
 		dic_restore		: 'Restore', // MISSING
 		dic_delete		: 'Delete', // MISSING
 		dic_rename		: 'Rename', // MISSING
-		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type it\'s name and click the Restore button.', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type its name and click the Restore button.', // MISSING
 
 		aboutTab		: 'About' // MISSING
 	},
@@ -716,6 +717,8 @@ CKEDITOR.lang['ms'] =
 	{
 		title		: 'About CKEditor', // MISSING
 		dlgTitle	: 'About CKEditor', // MISSING
+		help	: 'Check $1 for help.', // MISSING
+		userGuide : 'CKEditor User\'s Guide', // MISSING
 		moreInfo	: 'For licensing information please visit our web site:', // MISSING
 		copy		: 'Copyright &copy; $1. All rights reserved.' // MISSING
 	},
@@ -725,10 +728,11 @@ CKEDITOR.lang['ms'] =
 
 	fakeobjects :
 	{
-		anchor	: 'Anchor', // MISSING
-		flash	: 'Flash Animation', // MISSING
-		div		: 'Page Break', // MISSING
-		unknown	: 'Unknown Object' // MISSING
+		anchor		: 'Anchor', // MISSING
+		flash		: 'Flash Animation', // MISSING
+		iframe		: 'IFrame', // MISSING
+		hiddenfield	: 'Hidden Field', // MISSING
+		unknown		: 'Unknown Object' // MISSING
 	},
 
 	resize : 'Drag to resize', // MISSING
@@ -743,5 +747,66 @@ CKEDITOR.lang['ms'] =
 	},
 
 	toolbarCollapse	: 'Collapse Toolbar', // MISSING
-	toolbarExpand	: 'Expand Toolbar' // MISSING
+	toolbarExpand	: 'Expand Toolbar', // MISSING
+
+	toolbarGroups :
+	{
+		document : 'Document', // MISSING
+		clipboard : 'Clipboard/Undo', // MISSING
+		editing : 'Editing', // MISSING
+		forms : 'Forms', // MISSING
+		basicstyles : 'Basic Styles', // MISSING
+		paragraph : 'Paragraph', // MISSING
+		links : 'Links', // MISSING
+		insert : 'Insert', // MISSING
+		styles : 'Styles', // MISSING
+		colors : 'Colors', // MISSING
+		tools : 'Tools' // MISSING
+	},
+
+	bidi :
+	{
+		ltr : 'Text direction from left to right', // MISSING
+		rtl : 'Text direction from right to left' // MISSING
+	},
+
+	docprops :
+	{
+		label : 'Ciri-ciri dokumen',
+		title : 'Ciri-ciri dokumen',
+		design : 'Design', // MISSING
+		meta : 'Data Meta',
+		chooseColor : 'Choose', // MISSING
+		other : '<lain>',
+		docTitle :	'Tajuk Muka Surat',
+		charset : 	'Enkod Set Huruf',
+		charsetOther : 'Enkod Set Huruf yang Lain',
+		charsetASCII : 'ASCII', // MISSING
+		charsetCE : 'Central European', // MISSING
+		charsetCT : 'Chinese Traditional (Big5)', // MISSING
+		charsetCR : 'Cyrillic', // MISSING
+		charsetGR : 'Greek', // MISSING
+		charsetJP : 'Japanese', // MISSING
+		charsetKR : 'Korean', // MISSING
+		charsetTR : 'Turkish', // MISSING
+		charsetUN : 'Unicode (UTF-8)', // MISSING
+		charsetWE : 'Western European', // MISSING
+		docType : 'Jenis Kepala Dokumen',
+		docTypeOther : 'Jenis Kepala Dokumen yang Lain',
+		xhtmlDec : 'Masukkan pemula kod XHTML',
+		bgColor : 'Warna Latarbelakang',
+		bgImage : 'URL Gambar Latarbelakang',
+		bgFixed : 'Imej Latarbelakang tanpa Skrol',
+		txtColor : 'Warna Text',
+		margin : 'Margin Muka Surat',
+		marginTop : 'Atas',
+		marginLeft : 'Kiri',
+		marginRight : 'Kanan',
+		marginBottom : 'Bawah',
+		metaKeywords : 'Kata Kunci Indeks Dokumen (dipisahkan oleh koma)',
+		metaDescription : 'Keterangan Dokumen',
+		metaAuthor : 'Penulis',
+		metaCopyright : 'Hakcipta',
+		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
+	}
 };
