@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -34,8 +34,8 @@ CKEDITOR.lang['ru'] =
 	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
 
 	// ARIA descriptions.
-	toolbar	: 'Toolbar', // MISSING
-	editor	: 'Rich Text Editor', // MISSING
+	toolbars	: 'Editor toolbars', // MISSING
+	editor		: 'Rich Text Editor', // MISSING
 
 	// Toolbar buttons without dialogs.
 	source			: 'Источник',
@@ -56,6 +56,7 @@ CKEDITOR.lang['ru'] =
 	superscript		: 'Надстрочный индекс',
 	horizontalrule	: 'Вставить горизонтальную линию',
 	pagebreak		: 'Вставить разрыв страницы',
+	pagebreakAlt		: 'Page Break', // MISSING
 	unlink			: 'Убрать ссылку',
 	undo			: 'Отменить',
 	redo			: 'Повторить',
@@ -105,6 +106,23 @@ CKEDITOR.lang['ru'] =
 		targetTop		: 'Topmost Window (_top)', // MISSING
 		targetSelf		: 'Same Window (_self)', // MISSING
 		targetParent	: 'Parent Window (_parent)', // MISSING
+		langDirLTR		: 'Left to Right (LTR)', // MISSING
+		langDirRTL		: 'Right to Left (RTL)', // MISSING
+		styles			: 'Style', // MISSING
+		cssClasses		: 'Stylesheet Classes', // MISSING
+		width			: 'Ширина',
+		height			: 'Высота',
+		align			: 'Выравнивание',
+		alignLeft		: 'По левому краю',
+		alignRight		: 'По правому краю',
+		alignCenter		: 'По центру',
+		alignTop		: 'По верху',
+		alignMiddle		: 'Посередине',
+		alignBottom		: 'Понизу',
+		invalidHeight	: 'Высота задается числом.',
+		invalidWidth	: 'Ширина задается числом.',
+		invalidCssLength	: 'Value specified for the "%1" field must be a positive number with or without a valid CSS measurement unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
+		invalidHtmlLength	: 'Value specified for the "%1" field must be a positive number with or without a valid HTML measurement unit (px or %).', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, недоступно</span>'
@@ -151,9 +169,7 @@ CKEDITOR.lang['ru'] =
 		popupFullScreen	: 'Полный экран (IE)',
 		popupScrollBars	: 'Полосы прокрутки',
 		popupDependent	: 'Зависимый (Netscape)',
-		popupWidth		: 'Ширина',
 		popupLeft		: 'Позиция слева',
-		popupHeight		: 'Высота',
 		popupTop		: 'Позиция сверху',
 		id				: 'Id',
 		langDir			: 'Направление языка',
@@ -161,18 +177,19 @@ CKEDITOR.lang['ru'] =
 		langDirRTL		: 'Справа налево (RTL)',
 		acccessKey		: 'Горячая клавиша',
 		name			: 'Имя',
-		langCode		: 'Код языка',
-		tabIndex		: 'Последовательность перехода',
-		advisoryTitle	: 'Заголовок',
+		langCode			: 'Код языка',
+		tabIndex			: 'Последовательность перехода',
+		advisoryTitle		: 'Заголовок',
 		advisoryContentType	: 'Тип содержимого',
 		cssClasses		: 'Класс CSS',
 		charset			: 'Кодировка',
 		styles			: 'Стиль CSS',
-		selectAnchor	: 'Выберите якорь',
+		rel			: 'Relationship', // MISSING
+		selectAnchor		: 'Выберите якорь',
 		anchorName		: 'По имени якоря',
-		anchorId		: 'По идентификатору элемента',
-		emailAddress	: 'Адрес эл. почты',
-		emailSubject	: 'Заголовок сообщения',
+		anchorId			: 'По идентификатору элемента',
+		emailAddress		: 'Адрес эл. почты',
+		emailSubject		: 'Заголовок сообщения',
 		emailBody		: 'Тело сообщения',
 		noAnchors		: '(Нет якорей доступных в этом документе)',
 		noUrl			: 'Пожалуйста, введите URL ссылки',
@@ -186,7 +203,8 @@ CKEDITOR.lang['ru'] =
 		menu		: 'Свойства якоря',
 		title		: 'Свойства якоря',
 		name		: 'Имя якоря',
-		errorName	: 'Пожалуйста, введите имя якоря'
+		errorName	: 'Пожалуйста, введите имя якоря',
+		remove		: 'Remove Anchor' // MISSING
 	},
 
 	// List style dialog
@@ -196,6 +214,7 @@ CKEDITOR.lang['ru'] =
 		bulletedTitle		: 'Bulleted List Properties', // MISSING
 		type				: 'Type', // MISSING
 		start				: 'Start', // MISSING
+		validateStartNumber				:'List start number must be a whole number.', // MISSING
 		circle				: 'Circle', // MISSING
 		disc				: 'Disc', // MISSING
 		square				: 'Square', // MISSING
@@ -238,15 +257,9 @@ CKEDITOR.lang['ru'] =
 		rows		: 'Строки',
 		columns		: 'Колонки',
 		border		: 'Размер бордюра',
-		align		: 'Выравнивание',
-		alignLeft	: 'Слева',
-		alignCenter	: 'По центру',
-		alignRight	: 'Справа',
-		width		: 'Ширина',
 		widthPx		: 'пикселей',
 		widthPc		: 'процентов',
 		widthUnit	: 'width unit', // MISSING
-		height		: 'Высота',
 		cellSpace	: 'Промежуток (spacing)',
 		cellPad		: 'Отступ (padding)',
 		caption		: 'Заголовок',
@@ -282,9 +295,6 @@ CKEDITOR.lang['ru'] =
 			wordWrap		: 'Перенос по словам',
 			hAlign			: 'Выравнивание по горизонтали',
 			vAlign			: 'Выравнивание по вертикали',
-			alignTop		: 'По верху',
-			alignMiddle		: 'Посередине',
-			alignBottom		: 'По низу',
 			alignBaseline	: 'По базовой линии',
 			bgColor			: 'Цвет фона',
 			borderColor		: 'Цвет границы',
@@ -405,24 +415,16 @@ CKEDITOR.lang['ru'] =
 		btnUpload	: 'Отправить на сервер',
 		upload		: 'Закачать',
 		alt			: 'Альтернативный текст',
-		width		: 'Ширина',
-		height		: 'Высота',
 		lockRatio	: 'Сохранять пропорции',
-		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Сбросить размер',
 		border		: 'Бордюр',
 		hSpace		: 'Горизонтальный отступ',
 		vSpace		: 'Вертикальный отступ',
-		align		: 'Выравнивание',
-		alignLeft	: 'По левому краю',
-		alignRight	: 'По правому краю',
 		alertUrl	: 'Пожалуйста, введите URL изображения',
 		linkTab		: 'Ссылка',
 		button2Img	: 'Do you want to transform the selected image button on a simple image?',
 		img2Button	: 'Do you want to transform the selected image on a image button?',
 		urlMissing	: 'Отсутствует URL картинки.',
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
 		validateBorder	: 'Border must be a whole number.', // MISSING
 		validateHSpace	: 'HSpace must be a whole number.', // MISSING
 		validateVSpace	: 'VSpace must be a whole number.' // MISSING
@@ -446,16 +448,10 @@ CKEDITOR.lang['ru'] =
 		accessAlways	: 'Всегда',
 		accessSameDomain: 'Тот же домен',
 		accessNever		: 'Никогда',
-		align			: 'Выравнивание',
-		alignLeft		: 'По левому краю',
 		alignAbsBottom	: 'Абс понизу',
 		alignAbsMiddle	: 'Абс посередине',
 		alignBaseline	: 'По базовой линии',
-		alignBottom		: 'Понизу',
-		alignMiddle		: 'Посередине',
-		alignRight		: 'По правому краю',
 		alignTextTop	: 'Текст наверху',
-		alignTop		: 'По верху',
 		quality			: 'Качество',
 		qualityBest		: 'Лучшее',
 		qualityHigh		: 'Высокое',
@@ -469,13 +465,9 @@ CKEDITOR.lang['ru'] =
 		windowMode		: 'Оконный режим',
 		flashvars		: 'Переменные для Flash',
 		bgcolor			: 'Цвет фона',
-		width			: 'Ширина',
-		height			: 'Высота',
 		hSpace			: 'Горизонтальный отступ',
 		vSpace			: 'Вертикальный отступ',
 		validateSrc		: 'Пожалуйста, введите URL ссылки',
-		validateWidth	: 'Ширина задается числом.',
-		validateHeight	: 'Высота задается числом.',
 		validateHSpace	: 'Горизонтальный отступ задается числом.',
 		validateVSpace	: 'Вертикальный отступ задается числом.'
 	},
@@ -610,6 +602,15 @@ CKEDITOR.lang['ru'] =
 		remove				: 'Убрать Div'
   	},
 
+	iframe :
+	{
+		title		: 'IFrame Properties', // MISSING
+		toolbar		: 'IFrame', // MISSING
+		noUrl		: 'Please type the iframe URL', // MISSING
+		scrolling	: 'Enable scrollbars', // MISSING
+		border		: 'Show frame border' // MISSING
+	},
+
 	font :
 	{
 		label		: 'Шрифт',
@@ -707,7 +708,7 @@ CKEDITOR.lang['ru'] =
 		dic_restore		: 'Restore', // MISSING
 		dic_delete		: 'Delete', // MISSING
 		dic_rename		: 'Rename', // MISSING
-		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type it\'s name and click the Restore button.', // MISSING
+		dic_info		: 'Initially the User Dictionary is stored in a Cookie. However, Cookies are limited in size. When the User Dictionary grows to a point where it cannot be stored in a Cookie, then the dictionary may be stored on our server. To store your personal dictionary on our server you should specify a name for your dictionary. If you already have a stored dictionary, please type its name and click the Restore button.', // MISSING
 
 		aboutTab		: 'О словарях'
 	},
@@ -716,6 +717,8 @@ CKEDITOR.lang['ru'] =
 	{
 		title		: 'О программе CKEditor',
 		dlgTitle	: 'О программе CKEditor',
+		help	: 'Check $1 for help.', // MISSING
+		userGuide : 'CKEditor User\'s Guide', // MISSING
 		moreInfo	: 'По вопросам лицензирования обращайтесь на наш сайт:',
 		copy		: 'Copyright &copy; $1. Все права защищены.'
 	},
@@ -725,10 +728,11 @@ CKEDITOR.lang['ru'] =
 
 	fakeobjects :
 	{
-		anchor	: 'Якорь',
-		flash	: 'Flash-анимация',
-		div		: 'Разрыв страницы',
-		unknown	: 'Неизвестный объект'
+		anchor		: 'Якорь',
+		flash		: 'Flash-анимация',
+		iframe		: 'IFrame', // MISSING
+		hiddenfield	: 'Hidden Field', // MISSING
+		unknown		: 'Неизвестный объект'
 	},
 
 	resize : 'Перетащите для изменения размера',
@@ -743,5 +747,66 @@ CKEDITOR.lang['ru'] =
 	},
 
 	toolbarCollapse	: 'Свернуть панель инструментов',
-	toolbarExpand	: 'Развернуть панель инструментов'
+	toolbarExpand	: 'Развернуть панель инструментов',
+
+	toolbarGroups :
+	{
+		document : 'Document', // MISSING
+		clipboard : 'Clipboard/Undo', // MISSING
+		editing : 'Editing', // MISSING
+		forms : 'Forms', // MISSING
+		basicstyles : 'Basic Styles', // MISSING
+		paragraph : 'Paragraph', // MISSING
+		links : 'Links', // MISSING
+		insert : 'Insert', // MISSING
+		styles : 'Styles', // MISSING
+		colors : 'Colors', // MISSING
+		tools : 'Tools' // MISSING
+	},
+
+	bidi :
+	{
+		ltr : 'Text direction from left to right', // MISSING
+		rtl : 'Text direction from right to left' // MISSING
+	},
+
+	docprops :
+	{
+		label : 'Свойства документа',
+		title : 'Свойства документа',
+		design : 'Design', // MISSING
+		meta : 'Мета данные',
+		chooseColor : 'Выберите',
+		other : '<другой>',
+		docTitle :	'Заголовок страницы',
+		charset : 	'Кодировка набора символов',
+		charsetOther : 'Другая кодировка набора символов',
+		charsetASCII : 'ASCII', // MISSING
+		charsetCE : 'Центрально-европейская',
+		charsetCT : 'Китайская традиционная (Big5)',
+		charsetCR : 'Кириллица',
+		charsetGR : 'Греческая',
+		charsetJP : 'Японская',
+		charsetKR : 'Корейская',
+		charsetTR : 'Турецкая',
+		charsetUN : 'Юникод (UTF-8)',
+		charsetWE : 'Западно-европейская',
+		docType : 'Заголовок типа документа',
+		docTypeOther : 'Другой заголовок типа документа',
+		xhtmlDec : 'Включить XHTML объявления',
+		bgColor : 'Цвет фона',
+		bgImage : 'URL изображения фона',
+		bgFixed : 'Нескроллируемый фон',
+		txtColor : 'Цвет текста',
+		margin : 'Отступы страницы',
+		marginTop : 'Верхний',
+		marginLeft : 'Левый',
+		marginRight : 'Правый',
+		marginBottom : 'Нижний',
+		metaKeywords : 'Ключевые слова документа (разделенные запятой)',
+		metaDescription : 'Описание документа',
+		metaAuthor : 'Автор',
+		metaCopyright : 'Авторские права',
+		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
+	}
 };
